@@ -22,7 +22,7 @@
 
 #include <hydrogen/IO/AlsaAudioDriver.h>
 
-#ifdef H2CORE_HAVE_ALSA
+#if defined(H2CORE_HAVE_ALSA) || _DOXYGEN_
 
 #include <pthread.h>
 #include <iostream>
@@ -38,12 +38,14 @@ static int alsa_xrun_recovery( snd_pcm_t *handle, int err )
 	if ( err == -EPIPE ) {  /* under-run */
 		err = snd_pcm_prepare( handle );
 	} else if ( err == -ESTRPIPE ) {
-		while ( ( err = snd_pcm_resume( handle ) ) == -EAGAIN )
+		while ( ( err = snd_pcm_resume( handle ) ) == -EAGAIN ) {
 			sleep( 1 );     /* wait until the suspend flag is released */
+		}
 		if ( err < 0 ) {
 			err = snd_pcm_prepare( handle );
-			if ( err < 0 )
-				std::cerr << "Can't recovery from suspend, prepare failed: " << snd_strerror( err ) << std::endl;
+			if ( err < 0 ) {
+				std::cerr << "Can't recover from suspend, prepare failed: " << snd_strerror( err ) << std::endl;
+			}
 		}
 		return 0;
 	}
@@ -73,7 +75,7 @@ void* alsaAudioDriver_processCaller( void* param )
 	}
 
 	int nFrames = pDriver->m_nBufferSize;
-// 	_INFOLOG( "nFrames: " + to_string( nFrames ) );
+	__INFOLOG( QString( "nFrames: %1" ).arg( nFrames ) );
 	short pBuffer[ nFrames * 2 ];
 
 	float *pOut_L = pDriver->m_pOut_L;
@@ -81,7 +83,7 @@ void* alsaAudioDriver_processCaller( void* param )
 
 	while ( pDriver->m_bIsRunning ) {
 		// prepare the audio data
-		pDriver->m_processCallback( nFrames, NULL );
+		pDriver->m_processCallback( nFrames, nullptr );
 
 		for ( int i = 0; i < nFrames; ++i ) {
 			pBuffer[ i * 2 ] = ( short )( pOut_L[ i ] * 32768.0 );
@@ -92,20 +94,20 @@ void* alsaAudioDriver_processCaller( void* param )
 			__ERRORLOG( "XRUN" );
 
 			if ( alsa_xrun_recovery( pDriver->m_pPlayback_handle, err ) < 0 ) {
-				__ERRORLOG( "Can't recovery from XRUN" );
+				__ERRORLOG( "Can't recover from XRUN" );
 			}
 			// retry
 			if ( ( err = snd_pcm_writei( pDriver->m_pPlayback_handle, pBuffer, nFrames ) ) < 0 ) {
 				__ERRORLOG( "XRUN 2" );
 				if ( alsa_xrun_recovery( pDriver->m_pPlayback_handle, err ) < 0 ) {
-					__ERRORLOG( "Can't recovery from XRUN" );
+					__ERRORLOG( "Can't recover from XRUN" );
 				}
 			}
 
 			pDriver->m_nXRuns++;
 		}
 	}
-	return 0;
+	return nullptr;
 }
 
 
@@ -114,11 +116,11 @@ const char* AlsaAudioDriver::__class_name = "AlsaAudioDriver";
 AlsaAudioDriver::AlsaAudioDriver( audioProcessCallback processCallback )
 		: AudioOutput( __class_name )
 		, m_bIsRunning( false )
-		, m_pOut_L( NULL )
-		, m_pOut_R( NULL )
+		, m_pOut_L( nullptr )
+		, m_pOut_R( nullptr )
 		, m_nXRuns( 0 )
 		, m_nBufferSize( 0 )
-		, m_pPlayback_handle( NULL )
+		, m_pPlayback_handle( nullptr )
 		, m_processCallback( processCallback )
 {
 	INFOLOG( "INIT" );
@@ -148,7 +150,6 @@ int AlsaAudioDriver::connect()
 {
 	INFOLOG( "alsa device: " + m_sAlsaAudioDevice );
 	int nChannels = 2;
-	int period_size = m_nBufferSize / 2;
 
 	int err;
 
@@ -174,7 +175,7 @@ int AlsaAudioDriver::connect()
 
 	snd_pcm_hw_params_t *hw_params;
 	snd_pcm_hw_params_alloca( &hw_params );
-	if ( hw_params == NULL ) {
+	if ( hw_params == nullptr ) {
 		ERRORLOG( "error in snd_pcm_hw_params_alloca" );
 		return 1;
 	}
@@ -195,47 +196,45 @@ int AlsaAudioDriver::connect()
 		return 1;
 	}
 
-	snd_pcm_hw_params_set_rate_near( m_pPlayback_handle, hw_params, &m_nSampleRate, 0 );
+	snd_pcm_hw_params_set_rate_near( m_pPlayback_handle, hw_params, &m_nSampleRate, nullptr );
 
 	if ( ( err = snd_pcm_hw_params_set_channels( m_pPlayback_handle, hw_params, nChannels ) ) < 0 ) {
 		ERRORLOG( QString( "error in snd_pcm_hw_params_set_channels: %1" ).arg( QString::fromLocal8Bit(snd_strerror(err)) ) );
 		return 1;
 	}
 
+	// Configure buffer size, periods and period size. The user
+	// "BufferSize" setting defines the user's intention for the
+	// number of frames processed in a callback period. In ALSA, this
+	// is the "period", whereas the actual buffer (as reported by
+	// *_get_buffer_size) is sized to keep at least 2 periods' worth
+	// of data.
+	//
 	unsigned nPeriods = 2;
-	if ( ( err = snd_pcm_hw_params_set_periods_near( m_pPlayback_handle, hw_params, &nPeriods, 0 ) ) < 0 ) {
+	if ( ( err = snd_pcm_hw_params_set_periods_near( m_pPlayback_handle, hw_params, &nPeriods, nullptr ) ) < 0 ) {
 		ERRORLOG( QString( "error in snd_pcm_hw_params_set_periods: %1" ).arg( QString::fromLocal8Bit(snd_strerror(err)) ) );
 		return 1;
 	}
 	INFOLOG( QString( "nPeriods: %1" ).arg( nPeriods ) );
 
-	// Set buffer size (in frames). The resulting latency is given by
-	// latency = periodsize * periods / (rate * bytes_per_frame)
-//	m_nBufferSize = period_size * 2;
-//	infoLog( "buffer size preferita:" + to_string( m_nBufferSize ) );
+	snd_pcm_uframes_t period_size = m_nBufferSize;
 
-//	if ( ( err = snd_pcm_hw_params_set_buffer_size_near( m_pPlayback_handle, hw_params, &m_nBufferSize ) ) < 0 ) {
-//		errorLog( "[connect] error in snd_pcm_hw_params_set_buffer_size: " + string( QString::fromLocal8Bit(snd_strerror(err)) ) );
-//		return 1;
-//	}
-//	infoLog( "buffer size scelta:" + to_string( m_nBufferSize ) );
-
-	if ( ( err = snd_pcm_hw_params_set_period_size( m_pPlayback_handle, hw_params, period_size, 0 ) ) < 0 ) {
+	if ( ( err = snd_pcm_hw_params_set_period_size_near( m_pPlayback_handle, hw_params, &period_size, 0 ) ) < 0 ) {
 		ERRORLOG( QString( "error in snd_pcm_hw_params_set_period_size: %1" ).arg( QString::fromLocal8Bit(snd_strerror(err)) ) );
+		return 1;
 	}
-
+	m_nBufferSize = period_size;
 
 	if ( ( err = snd_pcm_hw_params( m_pPlayback_handle, hw_params ) ) < 0 ) {
 		ERRORLOG( QString( "error in snd_pcm_hw_params: %1" ).arg( QString::fromLocal8Bit(snd_strerror(err)) ) );
 		return 1;
 	}
 
-	snd_pcm_hw_params_get_rate( hw_params, &m_nSampleRate, 0 );
-	snd_pcm_hw_params_get_buffer_size( hw_params, &m_nBufferSize );
+	snd_pcm_hw_params_get_rate( hw_params, &m_nSampleRate, nullptr );
 
 	INFOLOG( QString( "*** PERIOD SIZE: %1" ).arg( period_size ) );
 	INFOLOG( QString( "*** SAMPLE RATE: %1" ).arg( m_nSampleRate ) );
-	INFOLOG( QString( "*** BUFFER SIZE: %1" ).arg( m_nBufferSize ) );
+	INFOLOG( QString( "*** BUFFER SIZE: %1" ).arg( nPeriods * m_nBufferSize ) );
 
 	//snd_pcm_hw_params_free( hw_params );
 
@@ -264,15 +263,15 @@ void AlsaAudioDriver::disconnect()
 
 	m_bIsRunning = false;
 
-	pthread_join( alsaAudioDriverThread, NULL );
+	pthread_join( alsaAudioDriverThread, nullptr );
 
 	snd_pcm_close( m_pPlayback_handle );
 
 	delete[] m_pOut_L;
-	m_pOut_L = NULL;
+	m_pOut_L = nullptr;
 
 	delete[] m_pOut_R;
-	m_pOut_R = NULL;
+	m_pOut_R = nullptr;
 }
 
 unsigned AlsaAudioDriver::getBufferSize()
@@ -323,7 +322,7 @@ void AlsaAudioDriver::locate( unsigned long nFrame )
 void AlsaAudioDriver::setBpm( float fBPM )
 {
 //	warningLog( "[setBpm] " + to_string(fBPM) );
-	m_transport.m_nBPM = fBPM;
+	m_transport.m_fBPM = fBPM;
 }
 
 };
