@@ -34,7 +34,7 @@
 #include <hydrogen/Preferences.h>
 #include <hydrogen/IO/CoreMidiDriver.h>
 
-#ifdef H2CORE_HAVE_COREMIDI
+#if defined(H2CORE_HAVE_COREMIDI) || _DOXYGEN_
 
 namespace H2Core
 {
@@ -109,8 +109,24 @@ CoreMidiDriver::CoreMidiDriver()
 
 	QString sMidiPortName = Preferences::get_instance()->m_sMidiPortName;
 	err = MIDIClientCreate ( CFSTR( "h2MIDIClient" ), NULL, NULL, &h2MIDIClient );
+	if ( err != noErr ) {
+		ERRORLOG( QString( "Cannot create CoreMIDI client: %1" ).arg( err ));
+	}
+
 	err = MIDIInputPortCreate ( h2MIDIClient, CFSTR( "h2InputPort" ), midiProc, this, &h2InputRef );
+	if ( err != noErr ) {
+		ERRORLOG( QString( "Cannot create CoreMIDI input port: %1" ).arg( err ));
+	}
+
 	err = MIDIOutputPortCreate ( h2MIDIClient, CFSTR( "h2OutputPort" ), &h2OutputRef );
+	if ( err != noErr ) {
+		ERRORLOG( QString( "Cannot create CoreMIDI output port: %1" ).arg( err ));
+	}
+
+	err = MIDISourceCreate ( h2MIDIClient, CFSTR( "Hydrogen" ), &h2VirtualOut );
+	if ( err != noErr ) {
+		ERRORLOG( QString( "Cannot create CoreMIDI virtual output: %1" ).arg( err ));
+	}
 }
 
 
@@ -158,7 +174,7 @@ void CoreMidiDriver::open()
 		cmH2Dst = MIDIGetDestination(0);
 	}
 
-	if (cmH2Dst != NULL) {
+	if (cmH2Dst != 0) {
 		CFStringRef H2MidiNames;
 
 		MIDIObjectGetStringProperty(cmH2Dst, kMIDIPropertyName, &H2MidiNames);
@@ -178,12 +194,44 @@ void CoreMidiDriver::close()
 	OSStatus err = noErr;
 	err = MIDIPortDisconnectSource( h2InputRef, cmH2Src );
 	err = MIDIPortDispose( h2InputRef );
+	err = MIDIEndpointDispose( h2VirtualOut );
 	//err = MIDIPortDisconnectSource( h2OutputRef, cmH2Dst );
 	//err = MIDIPortDispose( h2OutputRef );
 	err = MIDIClientDispose( h2MIDIClient );
 }
 
+std::vector<QString> CoreMidiDriver::getInputPortList()
+{
+	INFOLOG( "retrieving output list" );
+	OSStatus err = noErr;
 
+	std::vector<QString> cmPortList;
+	
+	cmSources = MIDIGetNumberOfDestinations();
+
+	INFOLOG ( "Getting number of MIDI sources . . .\n" );
+
+	unsigned i;
+	for ( i = 0; i < cmSources; i++ ) {
+		CFStringRef H2MidiNames;
+		cmH2Src = MIDIGetDestination( i );
+		if ( cmH2Src == 0 ) {
+			ERRORLOG( "Could not open output device" );
+		}
+		if ( cmH2Src ) {
+			err = MIDIObjectGetStringProperty( cmH2Src, kMIDIPropertyName, &H2MidiNames );
+			INFOLOG ( "Getting MIDI object string property . . .\n" );
+			char cmName[ 64 ];
+			CFStringGetCString( H2MidiNames, cmName, 64, kCFStringEncodingASCII );
+			INFOLOG ( "Getting MIDI object name . . .\n" );
+			QString h2MidiPortName = cmName;
+			cmPortList.push_back( h2MidiPortName );
+		}
+		CFRelease( H2MidiNames );
+	}
+
+	return cmPortList;
+}
 
 std::vector<QString> CoreMidiDriver::getOutputPortList()
 {
@@ -199,7 +247,7 @@ std::vector<QString> CoreMidiDriver::getOutputPortList()
 	for ( i = 0; i < cmSources; i++ ) {
 		CFStringRef H2MidiNames;
 		cmH2Src = MIDIGetSource( i );
-		if ( cmH2Src == NULL ) {
+		if ( cmH2Src == 0 ) {
 			ERRORLOG( "Could not open input device" );
 		}
 		if ( cmH2Src ) {
@@ -219,8 +267,8 @@ std::vector<QString> CoreMidiDriver::getOutputPortList()
 
 void CoreMidiDriver::handleQueueNote(Note* pNote)
 {
-	if (cmH2Dst == NULL ) {
-		ERRORLOG( "cmH2Dst = NULL " );
+	if (cmH2Dst == 0 ) {
+		ERRORLOG( "cmH2Dst = 0 " );
 		return;
 	}
 
@@ -241,20 +289,19 @@ void CoreMidiDriver::handleQueueNote(Note* pNote)
 	packetList.packet->data[1] = key;
 	packetList.packet->data[2] = velocity;
 
-
-	MIDISend(h2OutputRef, cmH2Dst, &packetList);
+	sendMidiPacket ( &packetList );
 
 	packetList.packet->data[0] = 0x90 | channel;
 	packetList.packet->data[1] = key;
 	packetList.packet->data[2] = velocity;
 
-	MIDISend(h2OutputRef, cmH2Dst, &packetList);
+	sendMidiPacket ( &packetList );
 }
 
 void CoreMidiDriver::handleQueueNoteOff( int channel, int key, int velocity )
 {
-	if (cmH2Dst == NULL ) {
-		ERRORLOG( "cmH2Dst = NULL " );
+	if (cmH2Dst == 0 ) {
+		ERRORLOG( "cmH2Dst = 0 " );
 		return;
 	}
 
@@ -275,14 +322,13 @@ void CoreMidiDriver::handleQueueNoteOff( int channel, int key, int velocity )
 	packetList.packet->data[1] = key;
 	packetList.packet->data[2] = velocity;
 
-
-	MIDISend(h2OutputRef, cmH2Dst, &packetList);
+	sendMidiPacket ( &packetList );
 }
 
 void CoreMidiDriver::handleQueueAllNoteOff()
 {
-	if (cmH2Dst == NULL ) {
-		ERRORLOG( "cmH2Dst = NULL " );
+	if (cmH2Dst == 0 ) {
+		ERRORLOG( "cmH2Dst = 0 " );
 		return;
 	}
 
@@ -307,8 +353,46 @@ void CoreMidiDriver::handleQueueAllNoteOff()
 		packetList.packet->data[1] = key;
 		packetList.packet->data[2] = 0;
 
-		MIDISend(h2OutputRef, cmH2Dst, &packetList);
+		sendMidiPacket ( &packetList );
+	}
+}
 
+void CoreMidiDriver::handleOutgoingControlChange( int param, int value, int channel )
+{
+	if (cmH2Dst == 0 ) {
+		ERRORLOG( "cmH2Dst = 0 " );
+		return;
+	}
+
+	if (channel < 0) {
+		return;
+	}
+
+	MIDIPacketList packetList;
+	packetList.numPackets = 1;
+
+	packetList.packet->timeStamp = 0;
+	packetList.packet->length = 3;
+	packetList.packet->data[0] = 0xB0 | channel;
+	packetList.packet->data[1] = param;
+	packetList.packet->data[2] = value;
+
+	sendMidiPacket ( &packetList );
+}
+
+
+void CoreMidiDriver::sendMidiPacket (MIDIPacketList *packetList)
+{
+	OSStatus err = noErr;
+
+	err = MIDISend(h2OutputRef, cmH2Dst, packetList);
+	if ( err != noErr ) {
+		ERRORLOG( QString( "Cannot send MIDI packet to output port: %1" ).arg( err ));
+	}
+
+	err = MIDIReceived(h2VirtualOut, packetList);
+	if ( err != noErr ) {
+		ERRORLOG( QString( "Cannot send MIDI packet to virtual output: %1" ).arg( err ));
 	}
 }
 
