@@ -25,6 +25,8 @@
 #include <hydrogen/helpers/xml.h>
 #include <hydrogen/basics/instrument.h>
 
+#include <set>
+
 namespace H2Core
 {
 
@@ -88,11 +90,10 @@ InstrumentList* InstrumentList::load_from( XMLNode* node, const QString& dk_path
 
 void InstrumentList::save_to( XMLNode* node, int component_id )
 {
-	XMLNode instruments_node = node->ownerDocument().createElement( "instrumentList" );
+	XMLNode instruments_node = node->createNode( "instrumentList" );
 	for ( int i = 0; i < size(); i++ ) {
 		( *this )[i]->save_to( &instruments_node, component_id );
 	}
-	node->appendChild( instruments_node );
 }
 
 void InstrumentList::operator<<( Instrument* instrument )
@@ -126,17 +127,28 @@ Instrument* InstrumentList::operator[]( int idx )
 {
 	if ( idx < 0 || idx >= __instruments.size() ) {
 		ERRORLOG( QString( "idx %1 out of [0;%2]" ).arg( idx ).arg( size() ) );
-		return 0;
+		return nullptr;
 	}
 	assert( idx >= 0 && idx < __instruments.size() );
 	return __instruments[idx];
 }
 
+bool InstrumentList::is_valid_index( int idx ) const
+{
+	bool is_valid_index = true;
+	
+	if ( idx < 0 || idx >= __instruments.size() ) {
+		is_valid_index = false;
+	}
+	
+	return is_valid_index;
+}
+
 Instrument* InstrumentList::get( int idx )
 {
-	if ( idx < 0 || idx >= __instruments.size() ) {
+	if ( !is_valid_index( idx ) ) {
 		ERRORLOG( QString( "idx %1 out of [0;%2]" ).arg( idx ).arg( size() ) );
-		return 0;
+		return nullptr;
 	}
 	assert( idx >= 0 && idx < __instruments.size() );
 	return __instruments[idx];
@@ -155,7 +167,7 @@ Instrument*  InstrumentList::find( const int id )
 	for( int i=0; i<__instruments.size(); i++ ) {
 		if ( __instruments[i]->get_id()==id ) return __instruments[i];
 	}
-	return 0;
+	return nullptr;
 }
 
 Instrument*  InstrumentList::find( const QString& name )
@@ -163,7 +175,7 @@ Instrument*  InstrumentList::find( const QString& name )
 	for( int i=0; i<__instruments.size(); i++ ) {
 		if ( __instruments[i]->get_name()==name ) return __instruments[i];
 	}
-	return 0;
+	return nullptr;
 }
 
 Instrument*  InstrumentList::findMidiNote( const int note )
@@ -171,7 +183,7 @@ Instrument*  InstrumentList::findMidiNote( const int note )
 	for( int i=0; i<__instruments.size(); i++ ) {
 		if ( __instruments[i]->get_midi_out_note()==note ) return __instruments[i];
 	}
-	return 0;
+	return nullptr;
 }
 
 Instrument* InstrumentList::del( int idx )
@@ -190,7 +202,7 @@ Instrument* InstrumentList::del( Instrument* instrument )
 			return instrument;
 		}
 	}
-	return 0;
+	return nullptr;
 }
 
 void InstrumentList::swap( int idx_a, int idx_b )
@@ -215,6 +227,35 @@ void InstrumentList::move( int idx_a, int idx_b )
 	__instruments.insert( __instruments.begin() + idx_b, tmp );
 }
 
+void InstrumentList::fix_issue_307()
+{
+	if ( has_all_midi_notes_same() ) {
+		WARNINGLOG( "Same MIDI note assigned to every instrument. Assigning default values." );
+		set_default_midi_out_notes();
+	}
+}
+
+bool InstrumentList::has_all_midi_notes_same() const
+{
+	if (__instruments.size() < 2) {
+		return false;
+	}
+
+	std::set<int> notes;
+	for( int i=0; i<__instruments.size(); i++ ) {
+		auto instr = __instruments[i];
+		notes.insert( instr->get_midi_out_note() );
+	}
+	return notes.size() == 1;
+}
+
+void InstrumentList::set_default_midi_out_notes()
+{
+	for( int i=0; i<__instruments.size(); i++ ) {
+		__instruments[i]->set_midi_out_note( i + 36 );
+	}
+}
+
 };
 
-/* vim: set softtabstop=4 expandtab: */
+/* vim: set softtabstop=4 noexpandtab: */
