@@ -50,7 +50,7 @@ Note::Note( Instrument* instrument, int position, float velocity, float pan_l, f
 	  __pitch( pitch ),
 	  __key( C ),
 	  __octave( P8 ),
-	  __adsr( 0 ),
+	  __adsr( nullptr ),
 	  __lead_lag( 0.0 ),
 	  __cut_off( 1.0 ),
 	  __resonance( 0.0 ),
@@ -62,14 +62,15 @@ Note::Note( Instrument* instrument, int position, float velocity, float pan_l, f
 	  __pattern_idx( 0 ),
 	  __midi_msg( -1 ),
 	  __note_off( false ),
-	  __just_recorded( false )
+	  __just_recorded( false ),
+	  __probability( 1.0f )
 {
-	if ( __instrument != 0 ) {
+	if ( __instrument != nullptr ) {
 		__adsr = __instrument->copy_adsr();
 		__instrument_id = __instrument->get_id();
 
 		for (std::vector<InstrumentComponent*>::iterator it = __instrument->get_components()->begin() ; it !=__instrument->get_components()->end(); ++it) {
-            InstrumentComponent *pCompo = *it;
+			InstrumentComponent *pCompo = *it;
 
 			SelectedLayerInfo *sampleInfo = new SelectedLayerInfo;
 			sampleInfo->SelectedLayer = -1;
@@ -96,7 +97,7 @@ Note::Note( Note* other, Instrument* instrument )
 	  __pitch( other->get_pitch() ),
 	  __key( other->get_key() ),
 	  __octave( other->get_octave() ),
-	  __adsr( 0 ),
+	  __adsr( nullptr ),
 	  __lead_lag( other->get_lead_lag() ),
 	  __cut_off( other->get_cut_off() ),
 	  __resonance( other->get_resonance() ),
@@ -108,29 +109,30 @@ Note::Note( Note* other, Instrument* instrument )
 	  __pattern_idx( other->get_pattern_idx() ),
 	  __midi_msg( other->get_midi_msg() ),
 	  __note_off( other->get_note_off() ),
-	  __just_recorded( other->get_just_recorded() )
+	  __just_recorded( other->get_just_recorded() ),
+	  __probability( other->get_probability() )
 {
-	if ( instrument != 0 ) __instrument = instrument;
-	if ( __instrument != 0 ) {
+	if ( instrument != nullptr ) __instrument = instrument;
+	if ( __instrument != nullptr ) {
 		__adsr = __instrument->copy_adsr();
 		__instrument_id = __instrument->get_id();
 
 		for (std::vector<InstrumentComponent*>::iterator it = __instrument->get_components()->begin() ; it !=__instrument->get_components()->end(); ++it) {
-            InstrumentComponent *pCompo = *it;
+			InstrumentComponent *pCompo = *it;
 
 			SelectedLayerInfo *sampleInfo = new SelectedLayerInfo;
 			sampleInfo->SelectedLayer = -1;
 			sampleInfo->SamplePosition = 0;
 
 			__layers_selected[ pCompo->get_drumkit_componentID() ] = sampleInfo;
-        }
+		}
 	}
 }
 
 Note::~Note()
 {
 	delete __adsr;
-	__adsr = 0;
+	__adsr = nullptr;
 }
 
 static inline float check_boundary( float v, float min, float max )
@@ -188,7 +190,7 @@ void Note::set_key_octave( const QString& str )
 	}
 	__octave = ( Octave )s_oct.toInt();
 	for( int i=KEY_MIN; i<=KEY_MAX; i++ ) {
-		if( __key_str[i]==s_key ){
+		if( __key_str[i]==s_key ) {
 			__key = ( Key )i;
 			return;
 		}
@@ -199,13 +201,13 @@ void Note::set_key_octave( const QString& str )
 void Note::dump()
 {
 	INFOLOG( QString( "Note : pos: %1\t humanize offset%2\t instr: %3\t key: %4\t pitch: %5" )
-			 .arg( __position )
-			 .arg( __humanize_delay )
-			 .arg( __instrument->get_name() )
-			 .arg( key_to_string() )
-			 .arg( __pitch )
-			 .arg( __note_off )
-		   );
+	         .arg( __position )
+	         .arg( __humanize_delay )
+	         .arg( __instrument->get_name() )
+	         .arg( key_to_string() )
+	         .arg( __pitch )
+	         .arg( __note_off )
+	       );
 }
 
 void Note::save_to( XMLNode* node )
@@ -220,27 +222,30 @@ void Note::save_to( XMLNode* node )
 	node->write_int( "length", __length );
 	node->write_int( "instrument", get_instrument()->get_id() );
 	node->write_bool( "note_off", __note_off );
+	node->write_float( "probability", __probability );
 }
 
 Note* Note::load_from( XMLNode* node, InstrumentList* instruments )
 {
 	Note* note = new Note(
-		0,
-		node->read_int( "position", 0 ),
-		node->read_float( "velocity", 0.8f ),
-		node->read_float( "pan_L", 0.5f ),
-		node->read_float( "pan_R", 0.5f ),
-		node->read_int( "length", -1 ),
-		node->read_float( "pitch", 0.0f )
+	    nullptr,
+	    node->read_int( "position", 0 ),
+	    node->read_float( "velocity", 0.8f ),
+	    node->read_float( "pan_L", 0.5f ),
+	    node->read_float( "pan_R", 0.5f ),
+	    node->read_int( "length", -1 ),
+	    node->read_float( "pitch", 0.0f )
 	);
 	note->set_lead_lag( node->read_float( "leadlag", 0, false, false ) );
 	note->set_key_octave( node->read_string( "key", "C0", false, false ) );
 	note->set_note_off( node->read_bool( "note_off", false, false, false ) );
 	note->set_instrument_id( node->read_int( "instrument", EMPTY_INSTR_ID ) );
 	note->map_instrument( instruments );
+	note->set_probability( node->read_float( "probability", 1.0f ));
+
 	return note;
 }
 
 };
 
-/* vim: set softtabstop=4 expandtab: */
+/* vim: set softtabstop=4 noexpandtab: */
