@@ -29,15 +29,16 @@
 
 #include "InstrumentEditorPanel.h"
 #include "../Skin.h"
+#include "../HydrogenApp.h"
 
 
-InstrumentEditorPanel* InstrumentEditorPanel::m_pInstance = NULL;
+InstrumentEditorPanel* InstrumentEditorPanel::m_pInstance = nullptr;
 const char* InstrumentEditorPanel::__class_name = "InstrumentEditorPanel";
 
 InstrumentEditorPanel* InstrumentEditorPanel::get_instance()
 {
-	if ( m_pInstance == NULL  ) {
-		m_pInstance = new InstrumentEditorPanel( NULL );
+	if ( m_pInstance == nullptr  ) {
+		m_pInstance = new InstrumentEditorPanel( nullptr );
 	}
 	return m_pInstance;
 }
@@ -52,7 +53,7 @@ InstrumentEditorPanel::InstrumentEditorPanel( QWidget *pParent )
 	INFOLOG( "INIT" );
 
 	m_pInstance = this;
-	m_pInstrumentEditor = new InstrumentEditor( 0 );
+	m_pInstrumentEditor = new InstrumentEditor( nullptr );
 
 	// LAYOUT
 	QGridLayout *vbox = new QGridLayout();
@@ -62,7 +63,9 @@ InstrumentEditorPanel::InstrumentEditorPanel( QWidget *pParent )
 	vbox->addWidget( m_pInstrumentEditor, 0, 0 );
 
 	this->setLayout( vbox );
-	m_pLayer = 0;
+	m_nLayer = 0;
+
+	HydrogenApp::get_instance()->addEventListener(this);
 }
 
 
@@ -72,6 +75,10 @@ InstrumentEditorPanel::~InstrumentEditorPanel()
 	INFOLOG( "DESTROY" );
 }
 
+void InstrumentEditorPanel::parametersInstrumentChangedEvent()
+{
+	notifyOfDrumkitChange();
+}
 
 void InstrumentEditorPanel::notifyOfDrumkitChange()
 {
@@ -84,7 +91,7 @@ void InstrumentEditorPanel::notifyOfDrumkitChange()
 void InstrumentEditorPanel::selectLayer( int nLayer )
 {
 	m_pInstrumentEditor->selectLayer( nLayer );
-	m_pLayer = nLayer;
+	m_nLayer = nLayer;
 }
 
 
