@@ -24,6 +24,9 @@
 #define WAVE_DISPLAY
 
 #include <QtGui>
+#if QT_VERSION >= 0x050000
+#  include <QtWidgets>
+#endif
 #include <hydrogen/object.h>
 
 namespace H2Core
@@ -40,15 +43,35 @@ class WaveDisplay : public QWidget, public H2Core::Object
 		WaveDisplay(QWidget* pParent);
 		~WaveDisplay();
 
-		void updateDisplay( H2Core::InstrumentLayer *pLayer );
+		virtual void	updateDisplay( H2Core::InstrumentLayer *pLayer );
 
-		void paintEvent(QPaintEvent *ev);
+		void			paintEvent( QPaintEvent *ev );
+		void			resizeEvent( QResizeEvent * event );
+		void			mouseDoubleClickEvent(QMouseEvent *ev);
+		
+		void			setSampleNameAlignment(Qt::AlignmentFlag flag);
 
-	private:
-		QPixmap m_background;
-		QString m_sSampleName;
-		int *m_pPeakData;
+	signals:
+		void doubleClicked(QWidget *pWidget);
+
+	protected:
+		Qt::AlignmentFlag			m_SampleNameAlignment;
+		QPixmap						m_Background;
+		QString						m_sSampleName;
+		int *						m_pPeakData;
+		
+		/*
+		 * Used to re-initialise m_pPeakData if width has changed
+		 */
+		
+		int							m_nCurrentWidth;
+		
+		H2Core::InstrumentLayer *	m_pLayer;
 };
 
+inline void WaveDisplay::setSampleNameAlignment(Qt::AlignmentFlag flag)
+{
+	m_SampleNameAlignment = flag;
+}
 
 #endif
