@@ -25,12 +25,12 @@
 #include <QPainter>
 
 #include "../InstrumentEditor/InstrumentEditor.h"
-#include "../widgets/Fader.h"
 #include "../HydrogenApp.h"
 #include "../Skin.h"
-#include "../widgets/Rotary.h"
-#include "../widgets/Button.h"
-#include "../widgets/LCD.h"
+#include "../Widgets/Fader.h"
+#include "../Widgets/Rotary.h"
+#include "../Widgets/Button.h"
+#include "../Widgets/LCD.h"
 
 #include <hydrogen/hydrogen.h>
 #include <hydrogen/Preferences.h>
@@ -63,7 +63,7 @@ MixerLine::MixerLine(QWidget* parent, int nInstr)
 	m_bIsSelected = false;
 	m_nPeakTimer = 0;
 
-	MidiAction* pAction;
+	Action* pAction;
 
 	resize( m_nWidth, m_nHeight );
 	setFixedSize( m_nWidth, m_nHeight );
@@ -79,7 +79,7 @@ MixerLine::MixerLine(QWidget* parent, int nInstr)
 			QSize( 18, 13 )
 	);
 	m_pPlaySampleBtn->move( 8, 2 );
-	m_pPlaySampleBtn->setToolTip( trUtf8( "Play sample" ) );
+	m_pPlaySampleBtn->setToolTip( tr( "Play sample" ) );
 	connect(m_pPlaySampleBtn, SIGNAL(clicked(Button*)), this, SLOT(click(Button*)));
 	connect(m_pPlaySampleBtn, SIGNAL(rightClicked(Button*)), this, SLOT(rightClick(Button*)));
 
@@ -103,7 +103,7 @@ MixerLine::MixerLine(QWidget* parent, int nInstr)
 			QSize( 18, 13 )
 	);
 	m_pMuteBtn->move( 8, 17 );
-	m_pMuteBtn->setToolTip( trUtf8( "Mute" ) );
+	m_pMuteBtn->setToolTip( tr( "Mute" ) );
 	connect(m_pMuteBtn, SIGNAL(clicked(Button*)), this, SLOT(click(Button*)));
 
 	// Solo button
@@ -115,14 +115,14 @@ MixerLine::MixerLine(QWidget* parent, int nInstr)
 			QSize( 18, 13 )
 	);
 	m_pSoloBtn->move( 30, 17);
-	m_pSoloBtn->setToolTip( trUtf8( "Solo" ) );
+	m_pSoloBtn->setToolTip( tr( "Solo" ) );
 	connect(m_pSoloBtn, SIGNAL(clicked(Button*)), this, SLOT(click(Button*)));
 
 	// pan rotary
-	m_pPanRotary = new Rotary( this, Rotary::TYPE_CENTER, trUtf8( "Pan" ), false, true);
+	m_pPanRotary = new Rotary( this, Rotary::TYPE_CENTER, tr( "Pan" ), false, true);
 	m_pPanRotary->move( 14, 32 );
 	connect( m_pPanRotary, SIGNAL( valueChanged(Rotary*) ), this, SLOT( panChanged(Rotary*) ) );
-	pAction = new MidiAction("PAN_ABSOLUTE");
+	pAction = new Action("PAN_ABSOLUTE");
 	pAction->setParameter1( QString::number(nInstr ));
 	pAction->setParameter2( QString::number( 1 ));
 	m_pPanRotary->setAction(pAction);
@@ -131,7 +131,7 @@ MixerLine::MixerLine(QWidget* parent, int nInstr)
 	uint y = 0;
 	for (uint i = 0; i < MAX_FX; i++) {
 		m_pKnob[i] = new Knob(this);
-		pAction = new MidiAction(QString( "EFFECT%1_LEVEL_ABSOLUTE" ).arg( QString::number(i+1) ));
+		pAction = new Action(QString( "EFFECT%1_LEVEL_ABSOLUTE" ).arg( QString::number(i+1) ));
 		pAction->setParameter1( QString::number( nInstr ) );
 		m_pKnob[i]->setAction( pAction );
 		if ( (i % 2) == 0 ) {
@@ -144,11 +144,11 @@ MixerLine::MixerLine(QWidget* parent, int nInstr)
 		connect( m_pKnob[i], SIGNAL( valueChanged(Knob*) ), this, SLOT( knobChanged(Knob*) ) );
 	}
 
-	Preferences *pref = Preferences::get_instance();
+	Preferences *pPref = Preferences::get_instance();
 
-	float m_fFalloffTemp = pref->getMixerFalloffSpeed();
-	m_fFalloffTemp = (m_fFalloffTemp * 20) - 2;
-	m_nFalloff = (int)m_fFalloffTemp;
+	float fFalloffTemp = pPref->getMixerFalloffSpeed();
+	fFalloffTemp = (fFalloffTemp * 20) - 2;
+	m_nFalloff = (int)fFalloffTemp;
 
 	QPixmap textBackground;
 	bool ok = textBackground.load( Skin::getImagePath() + "/mixerPanel/mixerline_text_background.png" );
@@ -159,7 +159,7 @@ MixerLine::MixerLine(QWidget* parent, int nInstr)
 	// instrument name widget
 	m_pNameWidget = new InstrumentNameWidget( this );
 	m_pNameWidget->move( 6, 128 );
-	m_pNameWidget->setToolTip( trUtf8( "Instrument name (double click to edit)" ) );
+	m_pNameWidget->setToolTip( tr( "Instrument name (double click to edit)" ) );
 	connect( m_pNameWidget, SIGNAL( doubleClicked () ), this, SLOT( nameClicked() ) );
 	connect( m_pNameWidget, SIGNAL( clicked () ), this, SLOT( nameSelected() ) );
 
@@ -170,7 +170,7 @@ MixerLine::MixerLine(QWidget* parent, int nInstr)
 	m_pFader->setMaxValue( 1.5 );
 	connect( m_pFader, SIGNAL( valueChanged(Fader*) ), this, SLOT( faderChanged(Fader*) ) );
 
-	pAction = new MidiAction("STRIP_VOLUME_ABSOLUTE");
+	pAction = new Action("STRIP_VOLUME_ABSOLUTE");
 	pAction->setParameter1( QString::number(nInstr) );
 	m_pFader->setAction( pAction );
 
@@ -183,16 +183,12 @@ MixerLine::MixerLine(QWidget* parent, int nInstr)
 	m_pPeakLCD->setPalette( lcdPalette );
 }
 
-
-
 MixerLine::~MixerLine()
 {
 //	INFOLOG( "DESTROY" );
 	//delete m_pFader;
 }
 
-
-
 void MixerLine::updateMixerLine()
 {
 	if ( m_nPeakTimer > m_nFalloff ) {
@@ -216,8 +212,6 @@ void MixerLine::updateMixerLine()
 	m_nPeakTimer++;
 }
 
-
-
 void MixerLine::click(Button *ref) {
 	Song *song = (Hydrogen::get_instance())->getSong();
 
@@ -234,8 +228,6 @@ void MixerLine::click(Button *ref) {
 	}
 }
 
-
-
 void MixerLine::rightClick(Button *ref)
 {
 	if (ref == m_pPlaySampleBtn) {
@@ -244,8 +236,6 @@ void MixerLine::rightClick(Button *ref)
 
 }
 
-
-
 void MixerLine::faderChanged(Fader *ref)
 {
 	Song *pSong = (Hydrogen::get_instance())->getSong();
@@ -253,49 +243,35 @@ void MixerLine::faderChanged(Fader *ref)
 	emit volumeChanged(this);
 
 	double value = (double) ref->getValue();
-	( HydrogenApp::get_instance() )->setStatusBarMessage( trUtf8( "Set instrument volume [%1]" ).arg( value, 0, 'f', 2 ), 2000 );
+	( HydrogenApp::get_instance() )->setStatusBarMessage( tr( "Set instrument volume [%1]" ).arg( value, 0, 'f', 2 ), 2000 );
 }
 
-
-
 bool MixerLine::isMuteClicked() {
 	return m_pMuteBtn->isPressed();
 }
 
-
-
 void MixerLine::setMuteClicked(bool isClicked) {
 	m_pMuteBtn->setPressed(isClicked);
 }
 
-
-
 bool MixerLine::isSoloClicked() {
 	return m_pSoloBtn->isPressed();
 }
 
-
-
 void MixerLine::setSoloClicked(bool isClicked) {
 	m_pSoloBtn->setPressed(isClicked);
 }
 
-
-
 float MixerLine::getVolume()
 {
 	return m_pFader->getValue();
 }
 
-
-
 void MixerLine::setVolume( float value )
 {
 	m_pFader->setValue( value );
 }
 
-
-
 void MixerLine::setPeak_L( float peak ) {
 	if (peak != getPeak_L() ) {
 		m_pFader->setPeak_L( peak );
@@ -318,14 +294,10 @@ void MixerLine::setPeak_L( float peak ) {
 	}
 }
 
-
-
 float MixerLine::getPeak_L() {
 	return m_pFader->getPeak_L();
 }
 
-
-
 void MixerLine::setPeak_R( float peak ) {
 	if (peak != getPeak_R() ) {
 		m_pFader->setPeak_R( peak );
@@ -348,30 +320,18 @@ void MixerLine::setPeak_R( float peak ) {
 	}
 }
 
-
-
 float MixerLine::getPeak_R() {
 	return m_pFader->getPeak_R();
 }
 
-
-
-
-
 void MixerLine::nameClicked() {
 	emit instrumentNameClicked(this);
 }
 
-
-
 void MixerLine::nameSelected() {
 	emit instrumentNameSelected(this);
 }
 
-
-
-
-
 void MixerLine::panChanged(Rotary *ref)
 {
 	Song *pSong = Hydrogen::get_instance()->getSong();
@@ -390,20 +350,16 @@ void MixerLine::panChanged(Rotary *ref)
 
 	char m_pFaderPos[100];
 	snprintf( m_pFaderPos, 99, "%#.2fL, %#.2fR",  pan_L, pan_R);
-	HydrogenApp::get_instance()->setStatusBarMessage( trUtf8( "Set instr. pan [%1]" ).arg( m_pFaderPos ), 2000 );
+	HydrogenApp::get_instance()->setStatusBarMessage( tr( "Set instr. pan [%1]" ).arg( m_pFaderPos ), 2000 );
 
 	m_pPanRotary->setToolTip( QString("Pan ") + QString( m_pFaderPos ) );
 }
 
-
-
 float MixerLine::getPan()
 {
 	return m_pPanRotary->getValue();
 }
 
-
-
 void MixerLine::setPan(float fValue)
 {
 	if ( fValue != m_pPanRotary->getValue() ) {
@@ -422,12 +378,10 @@ void MixerLine::setPan(float fValue)
 	}
 }
 
-
 void MixerLine::setPlayClicked( bool clicked ) {
 	m_pTriggerSampleLED->setPressed( clicked );
 }
 
-
 void MixerLine::knobChanged(Knob* pRef)
 {
 //	infoLog( "knobChanged" );
@@ -439,11 +393,10 @@ void MixerLine::knobChanged(Knob* pRef)
 	}
 }
 
-
 void MixerLine::setFXLevel( uint nFX, float fValue )
 {
-	if (nFX > MAX_FX) {
-		ERRORLOG( QString("[setFXLevel] nFX > MAX_FX (nFX=%1)").arg(nFX) );
+	if (nFX >= MAX_FX) {
+		ERRORLOG( QString("[setFXLevel] nFX >= MAX_FX (nFX=%1)").arg(nFX) );
 		return;
 	}
 	m_pKnob[nFX]->setValue( fValue );
@@ -451,14 +404,13 @@ void MixerLine::setFXLevel( uint nFX, float fValue )
 
 float MixerLine::getFXLevel(uint nFX)
 {
-	if (nFX > MAX_FX) {
-		ERRORLOG( QString("[setFXLevel] nFX > MAX_FX (nFX=%1)").arg(nFX) );
+	if (nFX >= MAX_FX) {
+		ERRORLOG( QString("[setFXLevel] nFX >= MAX_FX (nFX=%1)").arg(nFX) );
 		return 0.0f;
 	}
 	return m_pKnob[nFX]->getValue();
 }
 
-
 void MixerLine::setSelected( bool bIsSelected )
 {
 	if (m_bIsSelected == bIsSelected )	return;
@@ -483,7 +435,7 @@ ComponentMixerLine::ComponentMixerLine(QWidget* parent, int CompoID)
 {
 //	INFOLOG( "INIT" );
 
-    __compoID = CompoID;
+	__compoID = CompoID;
 
 	m_nWidth = MIXERLINE_WIDTH;
 	m_nHeight = MIXERLINE_HEIGHT;
@@ -506,7 +458,7 @@ ComponentMixerLine::ComponentMixerLine(QWidget* parent, int CompoID)
 			QSize( 18, 13 )
 	);
 	m_pMuteBtn->move( 8, 17 );
-	m_pMuteBtn->setToolTip( trUtf8( "Mute" ) );
+	m_pMuteBtn->setToolTip( tr( "Mute" ) );
 	connect(m_pMuteBtn, SIGNAL(clicked(Button*)), this, SLOT(click(Button*)));
 
 	// Solo button
@@ -518,17 +470,14 @@ ComponentMixerLine::ComponentMixerLine(QWidget* parent, int CompoID)
 			QSize( 18, 13 )
 	);
 	m_pSoloBtn->move( 30, 17);
-	m_pSoloBtn->setToolTip( trUtf8( "Solo" ) );
+	m_pSoloBtn->setToolTip( tr( "Solo" ) );
 	connect(m_pSoloBtn, SIGNAL(clicked(Button*)), this, SLOT(click(Button*)));
 
-	Preferences *pref = Preferences::get_instance();
+	Preferences *pPref = Preferences::get_instance();
 
-	QString family = pref->getMixerFontFamily();
-	int size = pref->getMixerFontPointSize();
-	QFont mixerFont( family, size );
-	float m_fFalloffTemp = pref->getMixerFalloffSpeed();
-	m_fFalloffTemp = (m_fFalloffTemp * 20) - 2;
-	m_nFalloff = (int)m_fFalloffTemp;
+	float fFalloffTemp = pPref->getMixerFalloffSpeed();
+	fFalloffTemp = (fFalloffTemp * 20) - 2;
+	m_nFalloff = (int)fFalloffTemp;
 
 	QPixmap textBackground;
 	bool ok = textBackground.load( Skin::getImagePath() + "/mixerPanel/mixerline_text_background.png" );
@@ -539,7 +488,7 @@ ComponentMixerLine::ComponentMixerLine(QWidget* parent, int CompoID)
 	// instrument name widget
 	m_pNameWidget = new InstrumentNameWidget( this );
 	m_pNameWidget->move( 6, 128 );
-	m_pNameWidget->setToolTip( trUtf8( "Component name" ) );
+	m_pNameWidget->setToolTip( tr( "Component name" ) );
 
 	// m_pFader
 	m_pFader = new Fader( this, false, false );
@@ -569,8 +518,6 @@ ComponentMixerLine::~ComponentMixerLine()
 	//delete m_pFader;
 }
 
-
-
 void ComponentMixerLine::updateMixerLine()
 {
 	if ( m_nPeakTimer > m_nFalloff ) {
@@ -594,8 +541,6 @@ void ComponentMixerLine::updateMixerLine()
 	m_nPeakTimer++;
 }
 
-
-
 void ComponentMixerLine::click(Button *ref) {
 	Song *pSong = (Hydrogen::get_instance())->getSong();
 
@@ -609,7 +554,6 @@ void ComponentMixerLine::click(Button *ref) {
 	}
 }
 
-
 void ComponentMixerLine::faderChanged(Fader *ref)
 {
 	Song *pSong = (Hydrogen::get_instance())->getSong();
@@ -617,49 +561,35 @@ void ComponentMixerLine::faderChanged(Fader *ref)
 	emit volumeChanged(this);
 
 	double value = (double) ref->getValue();
-	( HydrogenApp::get_instance() )->setStatusBarMessage( trUtf8( "Set instrument volume [%1]" ).arg( value, 0, 'f', 2 ), 2000 );
+	( HydrogenApp::get_instance() )->setStatusBarMessage( tr( "Set instrument volume [%1]" ).arg( value, 0, 'f', 2 ), 2000 );
 }
 
-
-
 bool ComponentMixerLine::isMuteClicked() {
 	return m_pMuteBtn->isPressed();
 }
 
-
-
 void ComponentMixerLine::setMuteClicked(bool isClicked) {
 	m_pMuteBtn->setPressed(isClicked);
 }
 
-
-
 bool ComponentMixerLine::isSoloClicked() {
 	return m_pSoloBtn->isPressed();
 }
 
-
-
 void ComponentMixerLine::setSoloClicked(bool isClicked) {
 	m_pSoloBtn->setPressed(isClicked);
 }
 
-
-
 float ComponentMixerLine::getVolume()
 {
 	return m_pFader->getValue();
 }
 
-
-
 void ComponentMixerLine::setVolume( float value )
 {
 	m_pFader->setValue( value );
 }
 
-
-
 void ComponentMixerLine::setPeak_L( float peak ) {
 	if (peak != getPeak_L() ) {
 		m_pFader->setPeak_L( peak );
@@ -682,14 +612,10 @@ void ComponentMixerLine::setPeak_L( float peak ) {
 	}
 }
 
-
-
 float ComponentMixerLine::getPeak_L() {
 	return m_pFader->getPeak_L();
 }
 
-
-
 void ComponentMixerLine::setPeak_R( float peak ) {
 	if (peak != getPeak_R() ) {
 		m_pFader->setPeak_R( peak );
@@ -712,17 +638,12 @@ void ComponentMixerLine::setPeak_R( float peak ) {
 	}
 }
 
-
-
 float ComponentMixerLine::getPeak_R() {
 	return m_pFader->getPeak_R();
 }
 
 
-
 // ::::::::::::::::::::::::::::
-
-
 const char* MasterMixerLine::__class_name = "MasterMixerLine";
 
 MasterMixerLine::MasterMixerLine(QWidget* parent)
@@ -742,12 +663,11 @@ MasterMixerLine::MasterMixerLine(QWidget* parent)
 	// Background image
 	setPixmap( "/mixerPanel/masterMixerline_background.png" );
 
-	Preferences *pref = Preferences::get_instance();
-	int size = pref->getMixerFontPointSize();
-	QString family = pref->getMixerFontFamily();
-	float m_fFalloffTemp = pref->getMixerFalloffSpeed();
-	m_fFalloffTemp = (m_fFalloffTemp * 20) - 2;
-	m_nFalloff = (int)m_fFalloffTemp;
+	Preferences *pPref = Preferences::get_instance();
+
+	float fFalloffTemp = pPref->getMixerFalloffSpeed();
+	fFalloffTemp = (fFalloffTemp * 20) - 2;
+	m_nFalloff = (int)fFalloffTemp;
 
 	m_pMasterFader = new MasterFader( this );
 	m_pMasterFader->setMin( 0.0 );
@@ -755,11 +675,9 @@ MasterMixerLine::MasterMixerLine(QWidget* parent)
 	m_pMasterFader->move( 24, MASTERMIXERLINE_FADER_H );
 	connect( m_pMasterFader, SIGNAL( valueChanged(MasterFader*) ), this, SLOT( faderChanged(MasterFader*) ) );
 
-	MidiAction* pAction = new MidiAction("MASTER_VOLUME_ABSOLUTE");
+	Action* pAction = new Action("MASTER_VOLUME_ABSOLUTE");
 	m_pMasterFader->setAction( pAction );
 
-	QFont mixerFont( family, size );
-
 	m_pPeakLCD = new LCDDisplay( this, LCDDigit::SMALL_BLUE, 4 );
 	m_pPeakLCD->move( 23, 53 );
 	m_pPeakLCD->setText( "0.00" );
@@ -767,15 +685,15 @@ MasterMixerLine::MasterMixerLine(QWidget* parent)
 	lcdPalette.setColor( QPalette::Background, QColor( 49, 53, 61 ) );
 	m_pPeakLCD->setPalette( lcdPalette );
 
-	m_pHumanizeVelocityRotary = new Rotary( this, Rotary::TYPE_NORMAL, trUtf8( "Humanize velocity" ), false, false );
+	m_pHumanizeVelocityRotary = new Rotary( this, Rotary::TYPE_NORMAL, tr( "Humanize velocity" ), false, false );
 	m_pHumanizeVelocityRotary->move( 74, 88 );
 	connect( m_pHumanizeVelocityRotary, SIGNAL( valueChanged(Rotary*) ), this, SLOT( rotaryChanged(Rotary*) ) );
 
-	m_pHumanizeTimeRotary = new Rotary( this, Rotary::TYPE_NORMAL, trUtf8( "Humanize time" ), false, false );
+	m_pHumanizeTimeRotary = new Rotary( this, Rotary::TYPE_NORMAL, tr( "Humanize time" ), false, false );
 	m_pHumanizeTimeRotary->move( 74, 125 );
 	connect( m_pHumanizeTimeRotary, SIGNAL( valueChanged(Rotary*) ), this, SLOT( rotaryChanged(Rotary*) ) );
 
-	m_pSwingRotary = new Rotary( this,  Rotary::TYPE_NORMAL, trUtf8( "Swing" ), false, false );
+	m_pSwingRotary = new Rotary( this,  Rotary::TYPE_NORMAL, tr( "Swing" ), false, false );
 	m_pSwingRotary->move( 74, 162 );
 	connect( m_pSwingRotary, SIGNAL( valueChanged(Rotary*) ), this, SLOT( rotaryChanged(Rotary*) ) );
 
@@ -789,26 +707,19 @@ MasterMixerLine::MasterMixerLine(QWidget* parent)
 	);
 	m_pMuteBtn->move( 20, 32 );
 	connect( m_pMuteBtn, SIGNAL( clicked(Button*) ), this, SLOT( muteClicked(Button*) ) );
-	m_pMuteBtn->setAction( new MidiAction("MUTE_TOGGLE"));
+	m_pMuteBtn->setAction( new Action("MUTE_TOGGLE"));
 }
 
-
-
-
 MasterMixerLine::~MasterMixerLine()
 {
 	m_fMaxPeak = 0.0;
 }
 
-
-
 void MasterMixerLine::muteClicked(Button* pBtn)
 {
-	Hydrogen::get_instance()->getSong()->__is_muted = pBtn->isPressed();
+	Hydrogen::get_instance()->getCoreActionController()->setMasterIsMuted( pBtn->isPressed() );
 }
 
-
-
 void MasterMixerLine::faderChanged(MasterFader *ref)
 {
 	m_pMasterFader->setValue( ref->getValue() );
@@ -819,26 +730,19 @@ void MasterMixerLine::faderChanged(MasterFader *ref)
 	pSong->set_is_modified( true );
 
 	double value = (double) ref->getValue();
-	( HydrogenApp::get_instance() )->setStatusBarMessage( trUtf8( "Set master volume [%1]" ).arg( value, 0, 'f', 2 ), 2000 );
+	( HydrogenApp::get_instance() )->setStatusBarMessage( tr( "Set master volume [%1]" ).arg( value, 0, 'f', 2 ), 2000 );
 }
 
-
-
-
 float MasterMixerLine::getVolume()
 {
 	return m_pMasterFader->getValue();
 }
 
-
-
 void MasterMixerLine::setVolume( float value )
 {
 	m_pMasterFader->setValue( value );
 }
 
-
-
 void MasterMixerLine::setPeak_L(float peak)
 {
 	if ( peak != getPeak_L() ) {
@@ -862,15 +766,10 @@ void MasterMixerLine::setPeak_L(float peak)
 	}
 }
 
-
-
-
 float MasterMixerLine::getPeak_L() {
 	return m_pMasterFader->getPeak_L();
 }
 
-
-
 void MasterMixerLine::setPeak_R(float peak) {
 	if ( peak != getPeak_R() ) {
 		m_pMasterFader->setPeak_R(peak);
@@ -893,14 +792,10 @@ void MasterMixerLine::setPeak_R(float peak) {
 	}
 }
 
-
-
 float MasterMixerLine::getPeak_R() {
 	return m_pMasterFader->getPeak_R();
 }
 
-
-
 void MasterMixerLine::updateMixerLine()
 {
 
@@ -936,7 +831,6 @@ void MasterMixerLine::updateMixerLine()
 	}
 }
 
-
 void MasterMixerLine::rotaryChanged( Rotary *pRef )
 {
 	QString sMsg;
@@ -947,15 +841,15 @@ void MasterMixerLine::rotaryChanged( Rotary *pRef )
 
 	if ( pRef == m_pHumanizeTimeRotary ) {
 		pEngine->getSong()->set_humanize_time_value( fVal );
-		sMsg = trUtf8( "Set humanize time parameter [%1]").arg( fVal, 0, 'f', 2 );
+		sMsg = tr( "Set humanize time parameter [%1]").arg( fVal, 0, 'f', 2 );
 	}
 	else if ( pRef == m_pHumanizeVelocityRotary ) {
 		pEngine->getSong()->set_humanize_velocity_value( fVal );
-		sMsg = trUtf8( "Set humanize velocity parameter [%1]").arg( fVal, 0, 'f', 2 );
+		sMsg = tr( "Set humanize velocity parameter [%1]").arg( fVal, 0, 'f', 2 );
 	}
 	else if ( pRef == m_pSwingRotary ) {
 		pEngine->getSong()->set_swing_factor( fVal );
-		sMsg = trUtf8( "Set swing factor [%1]").arg( fVal, 0, 'f', 2 );
+		sMsg = tr( "Set swing factor [%1]").arg( fVal, 0, 'f', 2 );
 	}
 	else {
 		ERRORLOG( "[knobChanged] Unhandled knob" );
@@ -966,9 +860,6 @@ void MasterMixerLine::rotaryChanged( Rotary *pRef )
 	( HydrogenApp::get_instance() )->setStatusBarMessage( sMsg, 2000 );
 }
 
-
-
-
 /////////////////////////////////////////
 
 
@@ -995,24 +886,17 @@ FxMixerLine::FxMixerLine(QWidget* parent)
 			QSize( 18, 12 )
 	);
 	activeBtn->move( 2, 5 );
-	activeBtn->setToolTip( trUtf8( "FX on/off") );
+	activeBtn->setToolTip( tr( "FX on/off") );
 	connect( activeBtn, SIGNAL( clicked(Button*) ), this, SLOT( click(Button*) ) );
 
-	Preferences *pref = Preferences::get_instance();
-
 	// m_pFader
 	m_pFader = new Fader( this, false, false );
 	m_pFader->move( 22, 106 );
 	connect( m_pFader, SIGNAL( valueChanged(Fader*) ), this, SLOT( faderChanged(Fader*) ) );
 
-	QString family = pref->getMixerFontFamily();
-	int size = pref->getMixerFontPointSize();
-	QFont mixerFont( family, size );
-
-
 	m_pNameWidget = new InstrumentNameWidget( this );
 	m_pNameWidget->move( 2, 106 );
-	m_pNameWidget->setText( trUtf8( "Master output" ) );
+	m_pNameWidget->setText( tr( "Master output" ) );
 
 	m_pPeakLCD = new LCDDisplay( this, LCDDigit::SMALL_BLUE, 4 );
 	m_pPeakLCD->move( 2, MIXERLINE_LABEL_H );
@@ -1054,29 +938,21 @@ void FxMixerLine::faderChanged(Fader *ref)
 		m_pPeakLCD->setSmallBlue();
 	}
 
-
 	Song *pSong = Hydrogen::get_instance()->getSong();
 	pSong->set_is_modified( true );
 	emit volumeChanged( this );
-
 }
 
-
-
 float FxMixerLine::getVolume()
 {
 	return m_pFader->getValue();
 }
 
-
-
 void FxMixerLine::setVolume( float value )
 {
 	m_pFader->setValue( value );
 }
 
-
-
 void FxMixerLine::setPeak_L( float peak )
 {
 	if (peak != getPeak_L() ) {
@@ -1097,16 +973,11 @@ void FxMixerLine::setPeak_L( float peak )
 	}
 }
 
-
-
 float FxMixerLine::getPeak_L()
 {
 	return m_pFader->getPeak_L();
 }
 
-
-
-
 void FxMixerLine::setPeak_R(float peak)
 {
 	if (peak != getPeak_R() ) {
@@ -1127,35 +998,21 @@ void FxMixerLine::setPeak_R(float peak)
 	}
 }
 
-
-
-
 float FxMixerLine::getPeak_R()
 {
 	return m_pFader->getPeak_R();
 }
 
-
-
-
 bool FxMixerLine::isFxActive()
 {
 	return activeBtn->isPressed();
 }
 
-
-
-
 void FxMixerLine::setFxActive( bool active )
 {
 	activeBtn->setPressed( active );
 }
 
-
-
-
-
-
 ////////////////////////////////
 
 InstrumentNameWidget::InstrumentNameWidget(QWidget* parent)
@@ -1165,9 +1022,9 @@ InstrumentNameWidget::InstrumentNameWidget(QWidget* parent)
 	m_nWidgetWidth = 17;
 	m_nWidgetHeight = 116;
 
-	Preferences *pref = Preferences::get_instance();
-	QString family = pref->getMixerFontFamily();
-	int size = pref->getMixerFontPointSize();
+	Preferences *pPref = Preferences::get_instance();
+	QString family = pPref->getMixerFontFamily();
+	int size = pPref->getMixerFontPointSize();
 	m_mixerFont.setFamily( family );
 	m_mixerFont.setPointSize( size );
 
@@ -1176,9 +1033,6 @@ InstrumentNameWidget::InstrumentNameWidget(QWidget* parent)
 	this->resize( m_nWidgetWidth, m_nWidgetHeight );
 }
 
-
-
-
 InstrumentNameWidget::~InstrumentNameWidget()
 {
 //	infoLog( "DESTROY" );
@@ -1198,9 +1052,6 @@ void InstrumentNameWidget::paintEvent( QPaintEvent* ev )
 	p.drawText( -m_nWidgetHeight + 5, 0, m_nWidgetHeight - 10, m_nWidgetWidth, Qt::AlignVCenter, m_sInstrName );
 }
 
-
-
-
 void InstrumentNameWidget::setText( QString text )
 {
 	if (m_sInstrName != text ) {
@@ -1209,31 +1060,23 @@ void InstrumentNameWidget::setText( QString text )
 	}
 }
 
-
-
 QString InstrumentNameWidget::text()
 {
 	return m_sInstrName;
 }
 
-
-
 void InstrumentNameWidget::mousePressEvent( QMouseEvent * e )
 {
 	UNUSED( e );
 	emit clicked();
 }
 
-
-
 void InstrumentNameWidget::mouseDoubleClickEvent( QMouseEvent * e )
 {
 	UNUSED( e );
 	emit doubleClicked();
 }
 
-
-
 // :::::::::::::::::::::
 
 
@@ -1256,7 +1099,7 @@ LadspaFXMixerLine::LadspaFXMixerLine(QWidget* parent)
 			QSize( 30, 13 )
 	);
 	m_pActiveBtn->move( 55, 25 );
-	m_pActiveBtn->setToolTip( trUtf8( "FX bypass") );
+	m_pActiveBtn->setToolTip( tr( "FX bypass") );
 	connect( m_pActiveBtn, SIGNAL( clicked(Button*) ), this, SLOT( click(Button*) ) );
 
 	// edit button
@@ -1268,17 +1111,18 @@ LadspaFXMixerLine::LadspaFXMixerLine(QWidget* parent)
 			QSize( 30, 13 )
 	);
 	m_pEditBtn->move( 87, 25 );
-	m_pEditBtn->setToolTip( trUtf8( "Edit FX parameters") );
+	m_pEditBtn->setToolTip( tr( "Edit FX parameters") );
 	connect( m_pEditBtn, SIGNAL( clicked(Button*) ), this, SLOT( click(Button*) ) );
 
 	// instrument name widget
 	m_pNameLCD = new LCDDisplay( this, LCDDigit::SMALL_BLUE, 13 );
 	m_pNameLCD->move( 11, 9 );
 	m_pNameLCD->setText( "No name" );
-	m_pNameLCD->setToolTip( trUtf8( "Ladspa FX name" ) );
+	m_pNameLCD->setToolTip( tr( "Ladspa FX name" ) );
 
 	// m_pRotary
-	m_pRotary = new Rotary( this,  Rotary::TYPE_NORMAL, trUtf8( "Effect return" ), false, false );
+	m_pRotary = new Rotary( this,  Rotary::TYPE_NORMAL, tr( "Effect return" ), false, false );
+	m_pRotary->setDefaultValue( m_pRotary->getMax() );
 	m_pRotary->move( 132, 4 );
 	connect( m_pRotary, SIGNAL( valueChanged(Rotary*) ), this, SLOT( rotaryChanged(Rotary*) ) );
 }
@@ -1290,8 +1134,6 @@ LadspaFXMixerLine::~LadspaFXMixerLine()
 //	infoLog( "DESTROY" );
 }
 
-
-
 void LadspaFXMixerLine::setName(QString name)
 {
 	m_pNameLCD->setText( name );
@@ -1307,23 +1149,16 @@ void LadspaFXMixerLine::click(Button *ref)
 	}
 }
 
-
-
 bool LadspaFXMixerLine::isFxActive()
 {
 	return !m_pActiveBtn->isPressed();
 }
 
-
-
-
 void LadspaFXMixerLine::setFxActive( bool active )
 {
 	m_pActiveBtn->setPressed( !active );
 }
 
-
-
 void LadspaFXMixerLine::rotaryChanged(Rotary *ref)
 {
 	UNUSED( ref );
@@ -1334,31 +1169,24 @@ void LadspaFXMixerLine::rotaryChanged(Rotary *ref)
 	emit volumeChanged(this);
 }
 
-
-
 void LadspaFXMixerLine::setPeaks( float fPeak_L, float fPeak_R )
 {
 	UNUSED( fPeak_L );
 	UNUSED( fPeak_R );
 }
 
-
-
 void LadspaFXMixerLine::getPeaks( float *fPeak_L, float *fPeak_R )
 {
 	UNUSED( fPeak_L );
 	UNUSED( fPeak_R );
 }
 
-
-
 float LadspaFXMixerLine::getVolume()
 {
 	return m_pRotary->getValue();
 }
 
 
-
 void LadspaFXMixerLine::setVolume(float value)
 {
 	m_pRotary->setValue( value );
