@@ -37,22 +37,27 @@ using namespace H2Core;
 
 #include "UndoActions.h"
 #include "PatternEditorPanel.h"
+#include "InstrumentEditor/InstrumentEditorPanel.h"
 #include "DrumPatternEditor.h"
 #include "../HydrogenApp.h"
 #include "../Mixer/Mixer.h"
-#include "../widgets/Button.h"
+#include "../Widgets/Button.h"
 
 #include <QtGui>
+#if QT_VERSION >= 0x050000
+#  include <QtWidgets>
+#endif
 #include <QClipboard>
 #include <cassert>
+#include <algorithm> // for std::min
 
 using namespace std;
 
 const char* InstrumentLine::__class_name = "InstrumentLine";
 
 InstrumentLine::InstrumentLine(QWidget* pParent)
-  : PixmapWidget(pParent, __class_name)
-  , m_bIsSelected(false)
+	: PixmapWidget(pParent, __class_name)
+	, m_bIsSelected(false)
 {
 	int h = Preferences::get_instance()->getPatternEditorGridHeight();
 	setFixedSize(181, h);
@@ -74,7 +79,7 @@ InstrumentLine::InstrumentLine(QWidget* pParent)
 	);
 	m_pMuteBtn->move( 145, 5 );
 	m_pMuteBtn->setPressed(false);
-	m_pMuteBtn->setToolTip( trUtf8("Mute instrument") );
+	m_pMuteBtn->setToolTip( tr("Mute instrument") );
 	connect(m_pMuteBtn, SIGNAL(clicked(Button*)), this, SLOT(muteClicked()));
 
 	m_pSoloBtn = new ToggleButton(
@@ -86,39 +91,42 @@ InstrumentLine::InstrumentLine(QWidget* pParent)
 	);
 	m_pSoloBtn->move( 163, 5 );
 	m_pSoloBtn->setPressed(false);
-	m_pSoloBtn->setToolTip( trUtf8("Solo") );
+	m_pSoloBtn->setToolTip( tr("Solo") );
 	connect(m_pSoloBtn, SIGNAL(clicked(Button*)), this, SLOT(soloClicked()));
 
 
 
 	// Popup menu
 	m_pFunctionPopup = new QMenu( this );
-	m_pFunctionPopup->addAction( trUtf8( "Clear notes" ), this, SLOT( functionClearNotes() ) );
+	m_pFunctionPopup->addAction( tr( "Clear notes" ), this, SLOT( functionClearNotes() ) );
 
-	m_pFunctionPopupSub = new QMenu( trUtf8( "Fill notes ..." ), m_pFunctionPopup );
-	m_pFunctionPopupSub->addAction( trUtf8( "Fill all notes" ), this, SLOT( functionFillAllNotes() ) );
-	m_pFunctionPopupSub->addAction( trUtf8( "Fill 1/2 notes" ), this, SLOT( functionFillEveryTwoNotes() ) );
-	m_pFunctionPopupSub->addAction( trUtf8( "Fill 1/3 notes" ), this, SLOT( functionFillEveryThreeNotes() ) );
-	m_pFunctionPopupSub->addAction( trUtf8( "Fill 1/4 notes" ), this, SLOT( functionFillEveryFourNotes() ) );
-	m_pFunctionPopupSub->addAction( trUtf8( "Fill 1/6 notes" ), this, SLOT( functionFillEverySixNotes() ) );
-	m_pFunctionPopupSub->addAction( trUtf8( "Fill 1/8 notes" ), this, SLOT( functionFillEveryEightNotes() ) );
+	m_pFunctionPopupSub = new QMenu( tr( "Fill notes ..." ), m_pFunctionPopup );
+	m_pFunctionPopupSub->addAction( tr( "Fill all notes" ), this, SLOT( functionFillAllNotes() ) );
+	m_pFunctionPopupSub->addAction( tr( "Fill 1/2 notes" ), this, SLOT( functionFillEveryTwoNotes() ) );
+	m_pFunctionPopupSub->addAction( tr( "Fill 1/3 notes" ), this, SLOT( functionFillEveryThreeNotes() ) );
+	m_pFunctionPopupSub->addAction( tr( "Fill 1/4 notes" ), this, SLOT( functionFillEveryFourNotes() ) );
+	m_pFunctionPopupSub->addAction( tr( "Fill 1/6 notes" ), this, SLOT( functionFillEverySixNotes() ) );
+	m_pFunctionPopupSub->addAction( tr( "Fill 1/8 notes" ), this, SLOT( functionFillEveryEightNotes() ) );
+	m_pFunctionPopupSub->addAction( tr( "Fill 1/12 notes" ), this, SLOT( functionFillEveryTwelveNotes() ) );
+	m_pFunctionPopupSub->addAction( tr( "Fill 1/16 notes" ), this, SLOT( functionFillEverySixteenNotes() ) );
 	m_pFunctionPopup->addMenu( m_pFunctionPopupSub );
 
-	m_pFunctionPopup->addAction( trUtf8( "Randomize velocity" ), this, SLOT( functionRandomizeVelocity() ) );
+	m_pFunctionPopup->addAction( tr( "Randomize velocity" ), this, SLOT( functionRandomizeVelocity() ) );
 	m_pFunctionPopup->addSeparator();
 
-	m_pCopyPopupSub = new QMenu( trUtf8( "Copy notes ..." ), m_pFunctionPopup );
-	m_pCopyPopupSub->addAction( trUtf8( "Only for this pattern" ), this, SLOT( functionCopyInstrumentPattern() ) );
-	m_pCopyPopupSub->addAction( trUtf8( "For all patterns" ), this, SLOT( functionCopyAllInstrumentPatterns() ) );
+	m_pCopyPopupSub = new QMenu( tr( "Copy notes ..." ), m_pFunctionPopup );
+	m_pCopyPopupSub->addAction( tr( "Only for this pattern" ), this, SLOT( functionCopyInstrumentPattern() ) );
+	m_pCopyPopupSub->addAction( tr( "For all patterns" ), this, SLOT( functionCopyAllInstrumentPatterns() ) );
 	m_pFunctionPopup->addMenu( m_pCopyPopupSub );
 
-	m_pPastePopupSub = new QMenu( trUtf8( "Paste notes ..." ), m_pFunctionPopup );
-	m_pPastePopupSub->addAction( trUtf8( "Only for this pattern" ), this, SLOT( functionPasteInstrumentPattern() ) );
-	m_pPastePopupSub->addAction( trUtf8( "For all patterns" ), this, SLOT( functionPasteAllInstrumentPatterns() ) );
+	m_pPastePopupSub = new QMenu( tr( "Paste notes ..." ), m_pFunctionPopup );
+	m_pPastePopupSub->addAction( tr( "Only for this pattern" ), this, SLOT( functionPasteInstrumentPattern() ) );
+	m_pPastePopupSub->addAction( tr( "For all patterns" ), this, SLOT( functionPasteAllInstrumentPatterns() ) );
 	m_pFunctionPopup->addMenu( m_pPastePopupSub );
 
 	m_pFunctionPopup->addSeparator();
-	m_pFunctionPopup->addAction( trUtf8( "Delete instrument" ), this, SLOT( functionDeleteInstrument() ) );
+	m_pFunctionPopup->addAction( tr( "Rename instrument" ), this, SLOT( functionRenameInstrument() ) );
+	m_pFunctionPopup->addAction( tr( "Delete instrument" ), this, SLOT( functionDeleteInstrument() ) );
 
 	m_bIsSelected = true;
 	setSelected(false);
@@ -171,12 +179,13 @@ void InstrumentLine::setSoloed( bool soloed )
 
 void InstrumentLine::muteClicked()
 {
-	Hydrogen *engine = Hydrogen::get_instance();
-	Song *song = engine->getSong();
-	InstrumentList *instrList = song->get_instrument_list();
+	Hydrogen *pEngine = Hydrogen::get_instance();
+	Song *pSong = pEngine->getSong();
+	InstrumentList *pInstrList = pSong->get_instrument_list();
+	Instrument *pInstr = pInstrList->get( m_nInstrumentNumber );
 
-	Instrument *pInstr = instrList->get(m_nInstrumentNumber);
-	pInstr->set_muted( !pInstr->is_muted());
+	CoreActionController* pCoreActionController = pEngine->getCoreActionController();
+	pCoreActionController->setStripIsMuted( m_nInstrumentNumber, !pInstr->is_muted() );
 }
 
 
@@ -194,7 +203,8 @@ void InstrumentLine::mousePressEvent(QMouseEvent *ev)
 	HydrogenApp::get_instance()->getPatternEditorPanel()->updatePianorollEditor();
 
 	if ( ev->button() == Qt::LeftButton ) {
-		const float velocity = 0.8f;
+		const int width = m_pMuteBtn->x() - 5; // clickable field width
+		const float velocity = std::min((float)ev->x()/(float)width, 1.0f);
 		const float pan_L = 0.5f;
 		const float pan_R = 0.5f;
 		const int nLength = -1;
@@ -220,14 +230,14 @@ H2Core::Pattern* InstrumentLine::getCurrentPattern()
 {
 	Hydrogen *pEngine = Hydrogen::get_instance();
 	PatternList *pPatternList = pEngine->getSong()->get_pattern_list();
-	assert( pPatternList != NULL );
+	assert( pPatternList != nullptr );
 
 	int nSelectedPatternNumber = pEngine->getSelectedPatternNumber();
 	if ( nSelectedPatternNumber != -1 ) {
 		Pattern* pCurrentPattern = pPatternList->get( nSelectedPatternNumber );
 		return pCurrentPattern;
 	}
-	return NULL;
+	return nullptr;
 }
 
 
@@ -251,7 +261,7 @@ void InstrumentLine::functionClearNotes()
 	}
 	if( noteList.size() > 0 ){
 		SE_clearNotesPatternEditorAction *action = new SE_clearNotesPatternEditorAction( noteList, m_nInstrumentNumber,selectedPatternNr);
-		HydrogenApp::get_instance()->m_undoStack->push( action );
+		HydrogenApp::get_instance()->m_pUndoStack->push( action );
 	}
 }
 
@@ -263,7 +273,7 @@ void InstrumentLine::functionCopyInstrumentPattern()
 	assert(song);
 
 	// Serialize & put to clipboard
-	QString serialized = LocalFileMng::copyInstrumentLineToString(song, selectedPatternNr, m_nInstrumentNumber);
+	QString serialized = song->copyInstrumentLineToString( selectedPatternNr, m_nInstrumentNumber );
 	QClipboard *clipboard = QApplication::clipboard();
 	clipboard->setText(serialized);
 }
@@ -275,7 +285,7 @@ void InstrumentLine::functionCopyAllInstrumentPatterns()
 	assert(song);
 
 	// Serialize & put to clipboard
-	QString serialized = LocalFileMng::copyInstrumentLineToString(song, -1, m_nInstrumentNumber);
+	QString serialized = song->copyInstrumentLineToString( -1, m_nInstrumentNumber );
 	QClipboard *clipboard = QApplication::clipboard();
 	clipboard->setText(serialized);
 }
@@ -305,7 +315,7 @@ void InstrumentLine::functionPasteInstrumentPatternExec(int patternID)
 	// Get from clipboard & deserialize
 	QClipboard *clipboard = QApplication::clipboard();
 	QString serialized = clipboard->text();
-	if (!LocalFileMng::pasteInstrumentLineFromString(song, serialized, patternID, m_nInstrumentNumber, patternList))
+	if ( !song->pasteInstrumentLineFromString( serialized, patternID, m_nInstrumentNumber, patternList ) )
 		return;
 
 	// Ignore empty result
@@ -314,7 +324,7 @@ void InstrumentLine::functionPasteInstrumentPatternExec(int patternID)
 
 	// Create action
 	SE_pasteNotesPatternEditorAction *action = new SE_pasteNotesPatternEditorAction(patternList);
-	HydrogenApp::get_instance()->m_undoStack->push(action);
+	HydrogenApp::get_instance()->m_pUndoStack->push(action);
 }
 
 
@@ -324,6 +334,8 @@ void InstrumentLine::functionFillEveryThreeNotes(){ functionFillNotes(3); }
 void InstrumentLine::functionFillEveryFourNotes(){ functionFillNotes(4); }
 void InstrumentLine::functionFillEverySixNotes(){ functionFillNotes(6); }
 void InstrumentLine::functionFillEveryEightNotes(){ functionFillNotes(8); }
+void InstrumentLine::functionFillEveryTwelveNotes(){ functionFillNotes(12); }
+void InstrumentLine::functionFillEverySixteenNotes(){ functionFillNotes(16); }
 
 void InstrumentLine::functionFillNotes( int every )
 {
@@ -346,7 +358,7 @@ void InstrumentLine::functionFillNotes( int every )
 	QStringList notePositions;
 
 	Pattern* pCurrentPattern = getCurrentPattern();
-	if (pCurrentPattern != NULL) {
+	if (pCurrentPattern != nullptr) {
 		int nPatternSize = pCurrentPattern->get_length();
 		int nSelectedInstrument = pEngine->getSelectedInstrumentNumber();
 
@@ -370,7 +382,7 @@ void InstrumentLine::functionFillNotes( int every )
 				}
 			}
 			SE_fillNotesRightClickAction *action = new SE_fillNotesRightClickAction( notePositions, nSelectedInstrument, pEngine->getSelectedPatternNumber() );
-			HydrogenApp::get_instance()->m_undoStack->push( action );
+			HydrogenApp::get_instance()->m_pUndoStack->push( action );
 		}
 	}
 
@@ -398,10 +410,10 @@ void InstrumentLine::functionRandomizeVelocity()
 	Song *pSong = pEngine->getSong();
 
 	QStringList noteVeloValue;
- 	QStringList oldNoteVeloValue;
+	QStringList oldNoteVeloValue;
 
 	Pattern* pCurrentPattern = getCurrentPattern();
-	if (pCurrentPattern != NULL) {
+	if (pCurrentPattern != nullptr) {
 		int nPatternSize = pCurrentPattern->get_length();
 		int nSelectedInstrument = pEngine->getSelectedInstrumentNumber();
 
@@ -427,14 +439,43 @@ void InstrumentLine::functionRandomizeVelocity()
 				}
 			}
 			SE_randomVelocityRightClickAction *action = new SE_randomVelocityRightClickAction( noteVeloValue, oldNoteVeloValue, nSelectedInstrument, pEngine->getSelectedPatternNumber() );
-			HydrogenApp::get_instance()->m_undoStack->push( action );
+			HydrogenApp::get_instance()->m_pUndoStack->push( action );
 		}
 	}
 }
 
 
 
+void InstrumentLine::functionRenameInstrument()
+{
+	// This code is pretty much a duplicate of void InstrumentEditor::labelClicked
+	// in InstrumentEditor.cpp
+	Hydrogen * pEngine = Hydrogen::get_instance();
+	Instrument *pSelectedInstrument = pEngine->getSong()->get_instrument_list()->get( m_nInstrumentNumber );
 
+	QString sOldName = pSelectedInstrument->get_name();
+	bool bIsOkPressed;
+	QString sNewName = QInputDialog::getText( this, "Hydrogen", tr( "New instrument name" ), QLineEdit::Normal, sOldName, &bIsOkPressed );
+	if ( bIsOkPressed  ) {
+		pSelectedInstrument->set_name( sNewName );
+
+#ifdef H2CORE_HAVE_JACK
+		AudioEngine::get_instance()->lock( RIGHT_HERE );
+		Hydrogen *engine = Hydrogen::get_instance();
+		engine->renameJackPorts(engine->getSong());
+		AudioEngine::get_instance()->unlock();
+#endif
+
+		// this will force an update...
+		EventQueue::get_instance()->push_event( EVENT_SELECTED_INSTRUMENT_CHANGED, -1 );
+
+	}
+	else
+	{
+		// user entered nothing or pressed Cancel
+	}
+
+}
 
 void InstrumentLine::functionDeleteInstrument()
 {
@@ -461,7 +502,7 @@ void InstrumentLine::functionDeleteInstrument()
 		}
 	}
 	SE_deleteInstrumentAction *action = new SE_deleteInstrumentAction( noteList, drumkitName, instrumentName, m_nInstrumentNumber );
-	HydrogenApp::get_instance()->m_undoStack->push( action );
+	HydrogenApp::get_instance()->m_pUndoStack->push( action );
 }
 
 
@@ -475,8 +516,8 @@ PatternEditorInstrumentList::PatternEditorInstrumentList( QWidget *parent, Patte
  , Object( __class_name )
 {
 	//INFOLOG("INIT");
-	m_pPattern = NULL;
- 	m_pPatternEditorPanel = pPatternEditorPanel;
+	m_pPattern = nullptr;
+	m_pPatternEditorPanel = pPatternEditorPanel;
 
 	m_nGridHeight = Preferences::get_instance()->getPatternEditorGridHeight();
 
@@ -489,7 +530,7 @@ PatternEditorInstrumentList::PatternEditorInstrumentList( QWidget *parent, Patte
 	setAcceptDrops(true);
 
 	for ( int i = 0; i < MAX_INSTRUMENTS; ++i) {
-		m_pInstrumentLine[i] = NULL;
+		m_pInstrumentLine[i] = nullptr;
 	}
 
 
@@ -542,7 +583,7 @@ void PatternEditorInstrumentList::updateInstrumentLines()
 		if ( nInstr >= nInstruments ) {	// unused instrument! let's hide and destroy the mixerline!
 			if ( m_pInstrumentLine[ nInstr ] ) {
 				delete m_pInstrumentLine[ nInstr ];
-				m_pInstrumentLine[ nInstr ] = NULL;
+				m_pInstrumentLine[ nInstr ] = nullptr;
 
 				int newHeight = m_nGridHeight * nInstruments;
 				resize( width(), newHeight );
@@ -551,7 +592,7 @@ void PatternEditorInstrumentList::updateInstrumentLines()
 			continue;
 		}
 		else {
-			if ( m_pInstrumentLine[ nInstr ] == NULL ) {
+			if ( m_pInstrumentLine[ nInstr ] == nullptr ) {
 				// the instrument line doesn't exists..I'll create a new one!
 				m_pInstrumentLine[ nInstr ] = createInstrumentLine();
 				m_pInstrumentLine[nInstr]->move( 0, m_nGridHeight * nInstr );
@@ -606,9 +647,14 @@ void PatternEditorInstrumentList::dropEvent(QDropEvent *event)
 		Hydrogen *engine = Hydrogen::get_instance();
 		int nSourceInstrument = engine->getSelectedInstrumentNumber();
 
-		int nTargetInstrument = event->pos().y() / m_nGridHeight;
+		// Starting point for instument list is 50 lower than
+		// on the drum pattern editor
 
-		if( nTargetInstrument > engine->getSong()->get_instrument_list()->size() ){
+		int pos_y = ( event->pos().x() >= m_nEditorWidth ) ? event->pos().y() - 50 : event->pos().y();
+
+		int nTargetInstrument = pos_y / m_nGridHeight;
+
+		if( nTargetInstrument >= engine->getSong()->get_instrument_list()->size() ){
 			nTargetInstrument = engine->getSong()->get_instrument_list()->size() - 1;
 		}
 
@@ -618,7 +664,7 @@ void PatternEditorInstrumentList::dropEvent(QDropEvent *event)
 		}
 
 		SE_moveInstrumentAction *action = new SE_moveInstrumentAction( nSourceInstrument, nTargetInstrument );
-		HydrogenApp::get_instance()->m_undoStack->push( action );
+		HydrogenApp::get_instance()->m_pUndoStack->push( action );
 
 		event->acceptProposedAction();
 	}
@@ -634,8 +680,8 @@ void PatternEditorInstrumentList::dropEvent(QDropEvent *event)
 		int nTargetInstrument = event->pos().y() / m_nGridHeight;
 
 		/*
-		    "X > 181": border between the instrument names on the left and the grid
-		    Because the right part of the grid starts above the name column, we have to subtract the difference
+				"X > 181": border between the instrument names on the left and the grid
+				Because the right part of the grid starts above the name column, we have to subtract the difference
 		*/
 		if (  event->pos().x() > 181 ) nTargetInstrument = ( event->pos().y() - 90 )  / m_nGridHeight ;
 
@@ -645,7 +691,7 @@ void PatternEditorInstrumentList::dropEvent(QDropEvent *event)
 		}
 
 		SE_dragInstrumentAction *action = new SE_dragInstrumentAction( sDrumkitName, sInstrumentName, nTargetInstrument);
-		HydrogenApp::get_instance()->m_undoStack->push( action );
+		HydrogenApp::get_instance()->m_pUndoStack->push( action );
 
 		event->acceptProposedAction();
 	}
@@ -684,11 +730,8 @@ void PatternEditorInstrumentList::mouseMoveEvent(QMouseEvent *event)
 	pMimeData->setText( sText );
 	pDrag->setMimeData( pMimeData);
 
-	pDrag->start( Qt::CopyAction | Qt::MoveAction );
+	pDrag->exec( Qt::CopyAction | Qt::MoveAction );
 
 	// propago l'evento
 	QWidget::mouseMoveEvent(event);
 }
-
-
-
