@@ -31,7 +31,7 @@
 
 #include <QPixmap>
 #include <QFontDialog>
-#include "widgets/MidiTable.h"
+#include "Widgets/MidiTable.h"
 
 #include <hydrogen/midi_map.h>
 #include <hydrogen/hydrogen.h>
@@ -54,8 +54,7 @@ PreferencesDialog::PreferencesDialog(QWidget* parent)
 {
 	setupUi( this );
 
-	setWindowTitle( trUtf8( "Preferences" ) );
-	setWindowIcon( QPixmap( Skin::getImagePath()  + "/icon16.png" ) );
+	setWindowTitle( tr( "Preferences" ) );
 
 	setMinimumSize( width(), height() );
 
@@ -119,6 +118,7 @@ PreferencesDialog::PreferencesDialog(QWidget* parent)
 	}
 
 	m_pIgnoreNoteOffCheckBox->setChecked( pPref->m_bMidiNoteOffIgnore );
+	m_pEnableMidiFeedbackCheckBox->setChecked( pPref->m_bEnableMidiFeedback );
 	m_pDiscardMidiMsgCheckbox->setChecked( pPref->m_bMidiDiscardNoteAfterAction );
 	m_pFixedMapping->setChecked( pPref->m_bMidiFixedMapping );
 
@@ -211,9 +211,9 @@ PreferencesDialog::PreferencesDialog(QWidget* parent)
 	int coloringMethodAuxValue = pPref->getColoringMethodAuxValue();
 
 	coloringMethodCombo->clear();
-	coloringMethodCombo->addItem(trUtf8("Automatic"));
-	coloringMethodCombo->addItem(trUtf8("Steps"));
-	coloringMethodCombo->addItem(trUtf8("Fixed"));
+	coloringMethodCombo->addItem(tr("Automatic"));
+	coloringMethodCombo->addItem(tr("Steps"));
+	coloringMethodCombo->addItem(tr("Fixed"));
 
 	coloringMethodAuxSpinBox->setMaximum(300);
 
@@ -228,7 +228,8 @@ PreferencesDialog::PreferencesDialog(QWidget* parent)
 	// midi tab
 	midiPortChannelComboBox->setEnabled( false );
 	midiPortComboBox->setEnabled( false );
-	// list midi output ports
+	
+	// list midi input ports
 	midiPortComboBox->clear();
 	midiPortComboBox->addItem( "None" );
 	if ( Hydrogen::get_instance()->getMidiInput() ) {
@@ -247,6 +248,26 @@ PreferencesDialog::PreferencesDialog(QWidget* parent)
 			}
 		}
 	}
+	
+	// list midi output ports
+	midiOutportComboBox->clear();
+	midiOutportComboBox->addItem( "None" );
+	if ( Hydrogen::get_instance()->getMidiOutput() ) {
+		std::vector<QString> midiOutList = Hydrogen::get_instance()->getMidiOutput()->getInputPortList();
+
+		if ( midiOutList.size() != 0 ) {
+			midiOutportComboBox->setEnabled( true );
+			midiPortChannelComboBox->setEnabled( true );
+		}
+		for (uint i = 0; i < midiOutList.size(); i++) {
+			QString sPortName = midiOutList[i];
+			midiOutportComboBox->addItem( sPortName );
+
+			if ( sPortName == pPref->m_sMidiOutputPortName ) {
+				midiOutportComboBox->setCurrentIndex( i + 1 );
+			}
+		}
+	}
 
 	if ( pPref->m_nMidiChannelFilter == -1 ) {
 		midiPortChannelComboBox->setCurrentIndex( 0 );
@@ -255,6 +276,14 @@ PreferencesDialog::PreferencesDialog(QWidget* parent)
 		midiPortChannelComboBox->setCurrentIndex( pPref->m_nMidiChannelFilter + 1 );
 	}
 
+	//OSC tab
+	enableOscCheckbox->setChecked( pPref->getOscServerEnabled() );
+	enableOscFeedbackCheckbox->setChecked( pPref->getOscFeedbackEnabled() );
+	connect(enableOscCheckbox, SIGNAL(toggled(bool)), this, SLOT(toggleOscCheckBox( bool )));
+	
+	incomingOscPortSpinBox->setValue( pPref->getOscServerPort() );
+	oscWidget->setEnabled( pPref->getOscServerEnabled() );
+	
 
 	// General tab
 	restoreLastUsedSongCheckbox->setChecked( pPref->isRestoreLastSongEnabled() );
@@ -275,6 +304,7 @@ PreferencesDialog::PreferencesDialog(QWidget* parent)
 	sBstartOffset->setValue( pPref->m_startOffset );
 
 	sBmaxBars->setValue( pPref->getMaxBars() );
+	sBmaxLayers->setValue( pPref->getMaxLayers() );
 
 	QString pathtoRubberband = pPref->m_rubberBandCLIexecutable;
 
@@ -412,16 +442,17 @@ void PreferencesDialog::on_okBtn_clicked()
 	pPref->m_bMidiNoteOffIgnore = m_pIgnoreNoteOffCheckBox->isChecked();
 	pPref->m_bMidiFixedMapping = m_pFixedMapping->isChecked();
 	pPref->m_bMidiDiscardNoteAfterAction = m_pDiscardMidiMsgCheckbox->isChecked();
-
+	pPref->m_bEnableMidiFeedback = m_pEnableMidiFeedbackCheckBox->isChecked();
+			
 	// Mixer falloff
 	QString falloffStr = mixerFalloffComboBox->currentText();
-	if ( falloffStr== trUtf8("Slow") ) {
+	if ( falloffStr== tr("Slow") ) {
 		pPref->setMixerFalloffSpeed(FALLOFF_SLOW);
 	}
-	else if ( falloffStr == trUtf8("Normal") ) {
+	else if ( falloffStr == tr("Normal") ) {
 		pPref->setMixerFalloffSpeed(FALLOFF_NORMAL);
 	}
-	else if ( falloffStr == trUtf8("Fast") ) {
+	else if ( falloffStr == tr("Fast") ) {
 		pPref->setMixerFalloffSpeed(FALLOFF_FAST);
 	}
 	else {
@@ -429,18 +460,27 @@ void PreferencesDialog::on_okBtn_clicked()
 	}
 
 	QString sNewMidiPortName = midiPortComboBox->currentText();
-
 	if ( pPref->m_sMidiPortName != sNewMidiPortName ) {
 		pPref->m_sMidiPortName = sNewMidiPortName;
 		m_bNeedDriverRestart = true;
 	}
+	
+	QString sNewMidiOutputPortName = midiOutportComboBox->currentText();
+	if ( pPref->m_sMidiOutputPortName != sNewMidiOutputPortName ) {
+		pPref->m_sMidiOutputPortName = sNewMidiOutputPortName;
+		m_bNeedDriverRestart = true;
+	}
 
 	if ( pPref->m_nMidiChannelFilter != midiPortChannelComboBox->currentIndex() - 1 ) {
 		//m_bNeedDriverRestart = true;
 	}
 	pPref->m_nMidiChannelFilter = midiPortChannelComboBox->currentIndex() - 1;
 
-
+	//OSC tab
+	pPref->setOscServerEnabled( enableOscCheckbox->isChecked() );
+	pPref->setOscFeedbackEnabled( enableOscFeedbackCheckbox->isChecked() );
+	pPref->setOscServerPort( incomingOscPortSpinBox->value() );
+	
 	// General tab
 	pPref->setRestoreLastSongEnabled( restoreLastUsedSongCheckbox->isChecked() );
 	pPref->setRestoreLastPlaylistEnabled( restoreLastUsedPlaylistCheckbox->isChecked() );
@@ -459,6 +499,7 @@ void PreferencesDialog::on_okBtn_clicked()
 	pPref->m_startOffset = sBstartOffset->value();
 
 	pPref->setMaxBars( sBmaxBars->value() );
+	pPref->setMaxLayers( sBmaxLayers->value() );
 
 	Hydrogen::get_instance()->setBcOffsetAdjust();
 
@@ -545,8 +586,14 @@ void PreferencesDialog::updateDriverInfo()
 #endif
 
 	if ( driverComboBox->currentText() == "Auto" ) {
-		info += trUtf8("<b>Automatic driver selection</b>");
-
+		info += tr("Automatic driver selection");
+		
+		// Display the selected driver as well.
+		if ( H2Core::Hydrogen::get_instance()->getAudioOutput() != nullptr ) {
+			info += tr("<br><b>")+
+				H2Core::Hydrogen::get_instance()->getAudioOutput()->class_name()+
+				tr("</b> selected");
+		}
 		m_pAudioDeviceTxt->setEnabled(false);
 		m_pAudioDeviceTxt->setText( "" );
 		bufferSizeSpinBox->setEnabled( false );
@@ -555,9 +602,9 @@ void PreferencesDialog::updateDriverInfo()
 		connectDefaultsCheckBox->setEnabled( false );
 	}
 	else if ( driverComboBox->currentText() == "OSS" ) {	// OSS
-		info += trUtf8("<b>Open Sound System</b><br>Simple audio driver [/dev/dsp]");
+		info += tr("<b>Open Sound System</b><br>Simple audio driver [/dev/dsp]");
 		if ( !bOss_support ) {
-			info += trUtf8("<br><b><font color=\"red\">Not compiled</font></b>");
+			info += tr("<br><b><font color=\"red\">Not compiled</font></b>");
 		}
 		m_pAudioDeviceTxt->setEnabled(true);
 		m_pAudioDeviceTxt->setText( pPref->m_sOSSDevice );
@@ -568,9 +615,9 @@ void PreferencesDialog::updateDriverInfo()
 		connectDefaultsCheckBox->setEnabled(false);
 	}
 	else if ( driverComboBox->currentText() == "Jack" ) {	// JACK
-		info += trUtf8("<b>Jack Audio Connection Kit Driver</b><br>Low latency audio driver");
+		info += tr("<b>Jack Audio Connection Kit Driver</b><br>Low latency audio driver");
 		if ( !bJack_support ) {
-			info += trUtf8("<br><b><font color=\"red\">Not compiled</font></b>");
+			info += tr("<br><b><font color=\"red\">Not compiled</font></b>");
 		}
 		m_pAudioDeviceTxt->setEnabled(false);
 		m_pAudioDeviceTxt->setText( "" );
@@ -581,9 +628,9 @@ void PreferencesDialog::updateDriverInfo()
 		trackOutsCheckBox->setEnabled( true );
 	}
 	else if ( driverComboBox->currentText() == "Alsa" ) {	// ALSA
-		info += trUtf8("<b>ALSA Driver</b><br>");
+		info += tr("<b>ALSA Driver</b><br>");
 		if ( !bAlsa_support ) {
-			info += trUtf8("<br><b><font color=\"red\">Not compiled</font></b>");
+			info += tr("<br><b><font color=\"red\">Not compiled</font></b>");
 		}
 		m_pAudioDeviceTxt->setEnabled(true);
 		m_pAudioDeviceTxt->setText( pPref->m_sAlsaAudioDevice );
@@ -594,9 +641,9 @@ void PreferencesDialog::updateDriverInfo()
 		connectDefaultsCheckBox->setEnabled(false);
 	}
 	else if ( driverComboBox->currentText() == "PortAudio" ) {
-		info += trUtf8( "<b>PortAudio Driver</b><br>" );
+		info += tr( "<b>PortAudio Driver</b><br>" );
 		if ( !bPortAudio_support ) {
-			info += trUtf8("<br><b><font color=\"red\">Not compiled</font></b>");
+			info += tr("<br><b><font color=\"red\">Not compiled</font></b>");
 		}
 		m_pAudioDeviceTxt->setEnabled(false);
 		m_pAudioDeviceTxt->setText( "" );
@@ -606,9 +653,9 @@ void PreferencesDialog::updateDriverInfo()
 		connectDefaultsCheckBox->setEnabled(false);
 	}
 	else if ( driverComboBox->currentText() == "CoreAudio" ) {
-		info += trUtf8( "<b>CoreAudio Driver</b><br>" );
+		info += tr( "<b>CoreAudio Driver</b><br>" );
 		if ( !bCoreAudio_support ) {
-			info += trUtf8("<br><b><font color=\"red\">Not compiled</font></b>");
+			info += tr("<br><b><font color=\"red\">Not compiled</font></b>");
 		}
 		m_pAudioDeviceTxt->setEnabled(false);
 		m_pAudioDeviceTxt->setText( "" );
@@ -619,9 +666,9 @@ void PreferencesDialog::updateDriverInfo()
 		connectDefaultsCheckBox->setEnabled(false);
 	}
 	else if ( driverComboBox->currentText() == "PulseAudio" ) {
-		info += trUtf8("<b>PulseAudio Driver</b><br>");
+		info += tr("<b>PulseAudio Driver</b><br>");
 		if ( !bPulseAudio_support ) {
-			info += trUtf8("<br><b><font color=\"red\">Not compiled</font></b>");
+			info += tr("<br><b><font color=\"red\">Not compiled</font></b>");
 		}
 		m_pAudioDeviceTxt->setEnabled(false);
 		m_pAudioDeviceTxt->setText("");
@@ -676,7 +723,7 @@ void PreferencesDialog::on_selectApplicationFontBtn_clicked()
 void PreferencesDialog::on_bufferSizeSpinBox_valueChanged( int i )
 {
 	UNUSED( i );
-	m_bNeedDriverRestart = false;
+	m_bNeedDriverRestart = true;
 }
 
 
@@ -719,15 +766,17 @@ void PreferencesDialog::on_selectMixerFontBtn_clicked()
 	mixerFontLbl->setText(family + QString("  %1").arg(pointSize));
 }
 
-
-
 void PreferencesDialog::on_midiPortComboBox_activated( int index )
 {
 	UNUSED( index );
 	m_bNeedDriverRestart = true;
 }
 
-
+void PreferencesDialog::on_midiOutportComboBox_activated( int index )
+{
+	UNUSED( index );
+	m_bNeedDriverRestart = true;
+}
 
 void PreferencesDialog::on_styleComboBox_activated( int index )
 {
@@ -751,7 +800,7 @@ void PreferencesDialog::on_useLashCheckbox_clicked()
 	{
 		Preferences::get_instance()->m_bsetLash = false ;
 	}
-	QMessageBox::information ( this, "Hydrogen", trUtf8 ( "Please restart hydrogen to enable/disable LASH support" ) );
+	QMessageBox::information ( this, "Hydrogen", tr ( "Please restart hydrogen to enable/disable LASH support" ) );
 }
 
 void PreferencesDialog::coloringMethodCombo_currentIndexChanged (int index)
@@ -763,12 +812,12 @@ void PreferencesDialog::coloringMethodCombo_currentIndexChanged (int index)
 			coloringMethodAuxSpinBox->hide();
 			break;
 		case 1:
-			coloringMethodAuxLabel->setText( trUtf8("Number of steps") );
+			coloringMethodAuxLabel->setText( tr("Number of steps") );
 			coloringMethodAuxSpinBox->setMinimum(1);
 			coloringMethodAuxSpinBox->show();
 			break;
 		case 2:
-			coloringMethodAuxLabel->setText( trUtf8("Color (Hue value)") );
+			coloringMethodAuxLabel->setText( tr("Color (Hue value)") );
 			coloringMethodAuxSpinBox->setMinimum(0);
 			coloringMethodAuxSpinBox->show();
 			break;
@@ -807,3 +856,8 @@ void PreferencesDialog::toggleTrackOutsCheckBox(bool toggled)
 	Preferences::get_instance()->m_bJackTrackOuts = toggled;
 	m_bNeedDriverRestart = true;
 }
+
+void PreferencesDialog::toggleOscCheckBox(bool toggled)
+{
+	oscWidget->setEnabled( toggled );
+}
