@@ -37,6 +37,9 @@
 #include <QFileDialog>
 #include <memory>
 #include <QtGui>
+#if QT_VERSION >= 0x050000
+#  include <QtWidgets>
+#endif
 #if defined(H2CORE_HAVE_LIBARCHIVE)
 #include <archive.h>
 #include <archive_entry.h>
@@ -54,7 +57,7 @@ SoundLibraryExportDialog::SoundLibraryExportDialog( QWidget* pParent,  const QSt
 {
 	setupUi( this );
 	INFOLOG( "INIT" );
-	setWindowTitle( trUtf8( "Export Sound Library" ) );
+	setWindowTitle( tr( "Export Sound Library" ) );
 	setFixedSize( width(), height() );
 	preselectedKit = selectedKit;
 	updateDrumkitList();
@@ -81,38 +84,40 @@ void SoundLibraryExportDialog::on_exportBtn_clicked()
 {
 	QApplication::setOverrideCursor(Qt::WaitCursor);
 
-	QString drumkitName = drumkitList->currentText();
-	QString drumkitDir = Filesystem::drumkit_dir_search( drumkitName );
-	QString saveDir = drumkitPathTxt->text();
-
-	Preferences *pref = Preferences::get_instance();
-	QDir qdTempFolder( pref->getTmpDirectory() );
+	QString		drumkitName = drumkitList->currentText();
+	QString		drumkitDir = Filesystem::drumkit_dir_search( drumkitName );
+	QString		saveDir = drumkitPathTxt->text();
+	Drumkit*	pDrumkit = nullptr;
+	
+	QDir qdTempFolder( Filesystem::tmp_dir() );
 	bool TmpFileCreated = false;
 
-
 	int componentID = -1;
-	Drumkit* info;
+	
 	if( versionList->currentIndex() == 1 ) {
 		for (uint i = 0; i < drumkitInfoList.size(); i++ ) {
-			info = drumkitInfoList[i];
-			if( info->get_name().compare( drumkitName ) == 0 ) {
+			pDrumkit = drumkitInfoList[i];
+			if( pDrumkit->get_name().compare( drumkitName ) == 0 ) {
 				QString temporaryDrumkitXML = qdTempFolder.filePath( "drumkit.xml" );
 				INFOLOG( "[ExportSoundLibrary]" );
 				INFOLOG( "Saving temporary file into: " + temporaryDrumkitXML );
 				TmpFileCreated = true;
-				for (std::vector<DrumkitComponent*>::iterator it = info->get_components()->begin() ; it != info->get_components()->end(); ++it) {
+
+				for (std::vector<DrumkitComponent*>::iterator it = pDrumkit->get_components()->begin() ; it != pDrumkit->get_components()->end(); ++it) {
 					DrumkitComponent* pComponent = *it;
 					if( pComponent->get_name().compare( componentList->currentText() ) == 0) {
 						componentID = pComponent->get_id();
 						break;
 					}
 				}
-				info->save_file( temporaryDrumkitXML, true, componentID );
+				pDrumkit->save_file( temporaryDrumkitXML, true, componentID );
 				break;
 			}
 		}
+		assert( pDrumkit );
 	}
 
+
 #if defined(H2CORE_HAVE_LIBARCHIVE)
 	QString fullDir = drumkitDir + "/" + drumkitName;
 	QDir sourceDir(fullDir);
@@ -139,7 +144,11 @@ void SoundLibraryExportDialog::on_exportBtn_clicked()
 	#endif
 
 	archive_write_set_format_pax_restricted(a);
-	archive_write_open_filename(a, outname.toUtf8().constData());
+	int ret = archive_write_open_filename(a, outname.toUtf8().constData());
+	if ( ret != ARCHIVE_OK ) {
+		QMessageBox::critical( this, "Hydrogen", QString("Couldn't create archive '%0'").arg( outname ) );
+		return;
+	}
 	for (int i = 0; i < filesList.size(); i++) {
 		QString filename = fullDir + "/" + filesList.at(i);
 		QString targetFilename = drumkitName + "/" + filesList.at(i);
@@ -150,13 +159,13 @@ void SoundLibraryExportDialog::on_exportBtn_clicked()
 			}
 			else {
 				bool bFoundFileInRightComponent = false;
-				for( int j = 0; j < info->get_instruments()->size() ; j++){
-					InstrumentList instrList = info->get_instruments();
+				for( int j = 0; j < pDrumkit->get_instruments()->size() ; j++){
+					InstrumentList instrList = pDrumkit->get_instruments();
 					Instrument* instr = instrList[j];
 					for (std::vector<InstrumentComponent*>::iterator it = instr->get_components()->begin() ; it != instr->get_components()->end(); ++it) {
 						InstrumentComponent* component = *it;
 						if( component->get_drumkit_componentID() == componentID ){
-							for( int n = 0; n < MAX_LAYERS; n++ ) {
+							for( int n = 0; n < InstrumentComponent::getMaxLayers(); n++ ) {
 								InstrumentLayer* layer = component->get_layer( n );
 								if( layer ) {
 									 if( layer->get_sample()->get_filename().compare(filesList.at(i)) == 0 ) {
@@ -168,8 +177,9 @@ void SoundLibraryExportDialog::on_exportBtn_clicked()
 						}
 					}
 				}
-				if( !bFoundFileInRightComponent )
+				if( !bFoundFileInRightComponent ) {
 					continue;
+				}
 			}
 		}
 
@@ -204,7 +214,6 @@ void SoundLibraryExportDialog::on_exportBtn_clicked()
 	QMessageBox::information( this, "Hydrogen", "Drumkit exported." );
 #elif !defined(WIN32)
 
-
 	if(TmpFileCreated)
 	{
 		/*
@@ -213,17 +222,17 @@ void SoundLibraryExportDialog::on_exportBtn_clicked()
 		 * 2. copy the temporary file to drumkitDir/drumkit.xml
 		 * 3. export the drumkit
 		 * 4. move the drumkit_backup.xml to drumkit.xml
-		 */ 
+		 */
 
 		int ret = 0;
 		
 		//1.
-		QString cmd = QString( "cd " ) + drumkitDir + "; " + "cp " + drumkitName + "/drumkit.xml " + drumkitName + "/drumkit_097.xml"; 
+		QString cmd = QString( "cd " ) + drumkitDir + "; " + "cp " + drumkitName + "/drumkit.xml " + drumkitName + "/drumkit_097.xml";
 		ret = system( cmd.toLocal8Bit() );
 		
 		
 		//2.
-		cmd = QString( "cd " ) + drumkitDir + "; " + "mv " + qdTempFolder.filePath( "drumkit.xml" ) + " " + drumkitName + "/drumkit.xml"; 
+		cmd = QString( "cd " ) + drumkitDir + "; " + "mv " + qdTempFolder.filePath( "drumkit.xml" ) + " " + drumkitName + "/drumkit.xml";
 		ret = system( cmd.toLocal8Bit() );
 		
 		//3.
@@ -231,7 +240,7 @@ void SoundLibraryExportDialog::on_exportBtn_clicked()
 		ret = system( cmd.toLocal8Bit() );
 
 		//4.
-		cmd = QString( "cd " ) + drumkitDir + "; " + "mv " + drumkitName + "/drumkit_097.xml " + drumkitName + "/drumkit.xml"; 
+		cmd = QString( "cd " ) + drumkitDir + "; " + "mv " + drumkitName + "/drumkit_097.xml " + drumkitName + "/drumkit.xml";
 		ret = system( cmd.toLocal8Bit() );
 
 	} else {
@@ -294,10 +303,11 @@ void SoundLibraryExportDialog::on_drumkitList_currentIndexChanged( QString str )
 
 void SoundLibraryExportDialog::on_versionList_currentIndexChanged( int index )
 {
-	if( index == 0 )
+	if( index == 0 ) {
 		componentList->setEnabled( false );
-	else if( index == 1 )
+	} else if( index == 1 ) {
 		componentList->setEnabled(  true );
+	}
 }
 
 void SoundLibraryExportDialog::updateDrumkitList()
@@ -312,10 +322,10 @@ void SoundLibraryExportDialog::updateDrumkitList()
 	}
 	drumkitInfoList.clear();
 
-	QStringList sysDrumkits = Filesystem::sys_drumkits_list();
+	QStringList sysDrumkits = Filesystem::sys_drumkit_list();
 	for (int i = 0; i < sysDrumkits.size(); ++i) {
-		QString absPath = Filesystem::sys_drumkits_dir() + "/" + sysDrumkits.at(i);
-		Drumkit *info = Drumkit::load( absPath );
+		QString absPath = Filesystem::sys_drumkits_dir() + sysDrumkits.at(i);
+		Drumkit *info = Drumkit::load( absPath, false );
 		if (info) {
 			drumkitInfoList.push_back( info );
 			drumkitList->addItem( info->get_name() );
@@ -328,10 +338,10 @@ void SoundLibraryExportDialog::updateDrumkitList()
 		}
 	}
 
-	QStringList userDrumkits = Filesystem::usr_drumkits_list();
+	QStringList userDrumkits = Filesystem::usr_drumkit_list();
 	for (int i = 0; i < userDrumkits.size(); ++i) {
-		QString absPath = Filesystem::usr_drumkits_dir() + "/" + userDrumkits.at(i);
-		Drumkit *info = Drumkit::load( absPath );
+		QString absPath = Filesystem::usr_drumkits_dir() + userDrumkits.at(i);
+		Drumkit *info = Drumkit::load( absPath, false );
 		if (info) {
 			drumkitInfoList.push_back( info );
 			drumkitList->addItem( info->get_name() );
