@@ -23,6 +23,9 @@
 #include "SoundLibraryPanel.h"
 
 #include <QtGui>
+#if QT_VERSION >= 0x050000
+#  include <QtWidgets>
+#endif
 
 #include "SoundLibraryDatastructures.h"
 #include "SoundLibraryTree.h"
@@ -33,15 +36,15 @@
 #include "SoundLibraryExportDialog.h"
 
 #include "../HydrogenApp.h"
-#include "../widgets/Button.h"
-#include "../widgets/PixmapWidget.h"
+#include "../Widgets/Button.h"
+#include "../Widgets/PixmapWidget.h"
 #include "../Skin.h"
 #include "../SongEditor/SongEditorPanel.h"
 #include "../PatternEditor/PatternEditorPanel.h"
 #include "../PatternEditor/DrumPatternEditor.h"
 #include "../PatternEditor/PatternEditorInstrumentList.h"
 #include "../InstrumentRack.h"
-#include "../InstrumentEditor/InstrumentEditorPanel.h" 
+#include "../InstrumentEditor/InstrumentEditorPanel.h"
 
 #include <hydrogen/LocalFileMng.h>
 #include <hydrogen/basics/adsr.h>
@@ -63,54 +66,56 @@ using namespace H2Core;
 
 const char* SoundLibraryPanel::__class_name = "SoundLibraryPanel";
 
-SoundLibraryPanel::SoundLibraryPanel( QWidget *pParent )
+SoundLibraryPanel::SoundLibraryPanel( QWidget *pParent, bool bInItsOwnDialog )
  : QWidget( pParent )
  , Object( __class_name )
- , __sound_library_tree( NULL )
- , __drumkit_menu( NULL )
- , __instrument_menu( NULL )
- , __song_menu( NULL )
- , __pattern_menu( NULL )
- , __pattern_menu_list( NULL )
- , __system_drumkits_item( NULL )
- , __user_drumkits_item( NULL )
- , __song_item( NULL )
- , __pattern_item( NULL )
- , __pattern_item_list( NULL )
+ , __sound_library_tree( nullptr )
+ , __drumkit_menu( nullptr )
+ , __instrument_menu( nullptr )
+ , __song_menu( nullptr )
+ , __pattern_menu( nullptr )
+ , __pattern_menu_list( nullptr )
+ , __system_drumkits_item( nullptr )
+ , __user_drumkits_item( nullptr )
+ , __song_item( nullptr )
+ , __pattern_item( nullptr )
+ , __pattern_item_list( nullptr )
 {
 
 	//INFOLOG( "INIT" );
 	__drumkit_menu = new QMenu( this );
-	__drumkit_menu->addAction( trUtf8( "Load" ), this, SLOT( on_drumkitLoadAction() ) );
-	__drumkit_menu->addAction( trUtf8( "Export" ), this, SLOT( on_drumkitExportAction() ) );
-	__drumkit_menu->addAction( trUtf8( "Properties" ), this, SLOT( on_drumkitPropertiesAction() ) );
+	__drumkit_menu->addAction( tr( "Load" ), this, SLOT( on_drumkitLoadAction() ) );
+	__drumkit_menu->addAction( tr( "Export" ), this, SLOT( on_drumkitExportAction() ) );
+	__drumkit_menu->addAction( tr( "Properties" ), this, SLOT( on_drumkitPropertiesAction() ) );
 	__drumkit_menu->addSeparator();
-	__drumkit_menu->addAction( trUtf8( "Delete" ), this, SLOT( on_drumkitDeleteAction() ) );
+	__drumkit_menu->addAction( tr( "Delete" ), this, SLOT( on_drumkitDeleteAction() ) );
 
 	__instrument_menu = new QMenu( this );
 	__instrument_menu->addSeparator();
-	__instrument_menu->addAction( trUtf8( "Delete" ), this, SLOT( on_instrumentDeleteAction() ) );
+	__instrument_menu->addAction( tr( "Delete" ), this, SLOT( on_instrumentDeleteAction() ) );
 
 	__song_menu = new QMenu( this );
 	__song_menu->addSeparator();
-	__song_menu->addAction( trUtf8( "Load" ), this, SLOT( on_songLoadAction() ) );
+	__song_menu->addAction( tr( "Load" ), this, SLOT( on_songLoadAction() ) );
 
 	__pattern_menu = new QMenu( this );
 	__pattern_menu->addSeparator();
-	__pattern_menu->addAction( trUtf8( "Load" ), this, SLOT( on_patternLoadAction() ) );
-	__pattern_menu->addAction( trUtf8( "Delete" ), this, SLOT( on_patternDeleteAction() ) );
+	__pattern_menu->addAction( tr( "Load" ), this, SLOT( on_patternLoadAction() ) );
+	__pattern_menu->addAction( tr( "Delete" ), this, SLOT( on_patternDeleteAction() ) );
 
 	__pattern_menu_list = new QMenu( this );
 	__pattern_menu_list->addSeparator();
-	__pattern_menu_list->addAction( trUtf8( "Load" ), this, SLOT( on_patternLoadAction() ) );
+	__pattern_menu_list->addAction( tr( "Load" ), this, SLOT( on_patternLoadAction() ) );
 
 // DRUMKIT LIST
-	__sound_library_tree = new SoundLibraryTree( NULL );
+	__sound_library_tree = new SoundLibraryTree( nullptr );
 	connect( __sound_library_tree, SIGNAL( currentItemChanged ( QTreeWidgetItem*, QTreeWidgetItem* ) ), this, SLOT( on_DrumkitList_ItemChanged( QTreeWidgetItem*, QTreeWidgetItem* ) ) );
 	connect( __sound_library_tree, SIGNAL( itemActivated ( QTreeWidgetItem*, int ) ), this, SLOT( on_DrumkitList_itemActivated( QTreeWidgetItem*, int ) ) );
 	connect( __sound_library_tree, SIGNAL( leftClicked(QPoint) ), this, SLOT( on_DrumkitList_leftClicked(QPoint)) );
-	connect( __sound_library_tree, SIGNAL( rightClicked(QPoint) ), this, SLOT( on_DrumkitList_rightClicked(QPoint)) );
-	connect( __sound_library_tree, SIGNAL( onMouseMove( QMouseEvent* ) ), this, SLOT( on_DrumkitList_mouseMove( QMouseEvent* ) ) );
+	if( !bInItsOwnDialog ) {
+		connect( __sound_library_tree, SIGNAL( rightClicked(QPoint) ), this, SLOT( on_DrumkitList_rightClicked(QPoint)) );
+		connect( __sound_library_tree, SIGNAL( onMouseMove( QMouseEvent* ) ), this, SLOT( on_DrumkitList_mouseMove( QMouseEvent* ) ) );
+	}
 
 
 	// LAYOUT
@@ -158,12 +163,12 @@ void SoundLibraryPanel::updateDrumkitList()
 
 
 	__system_drumkits_item = new QTreeWidgetItem( __sound_library_tree );
-	__system_drumkits_item->setText( 0, trUtf8( "System drumkits" ) );
-	__sound_library_tree->setItemExpanded( __system_drumkits_item, true );
+	__system_drumkits_item->setText( 0, tr( "System drumkits" ) );
+	__system_drumkits_item->setExpanded( true );
 
 	__user_drumkits_item = new QTreeWidgetItem( __sound_library_tree );
-	__user_drumkits_item->setText( 0, trUtf8( "User drumkits" ) );
-	__sound_library_tree->setItemExpanded( __user_drumkits_item, true );
+	__user_drumkits_item->setText( 0, tr( "User drumkits" ) );
+	__user_drumkits_item->setExpanded( true );
 
 	
 
@@ -178,16 +183,16 @@ void SoundLibraryPanel::updateDrumkitList()
 	__user_drumkit_info_list.clear();
 
 	//User drumkit list
-	QStringList usr_dks = Filesystem::usr_drumkits_list();
+	QStringList usr_dks = Filesystem::usr_drumkit_list();
 	for (int i = 0; i < usr_dks.size(); ++i) {
-		QString absPath = Filesystem::usr_drumkits_dir() + "/" + usr_dks[i];
-		Drumkit *pInfo = Drumkit::load( absPath );
+		QString absPath = Filesystem::usr_drumkits_dir() + usr_dks[i];
+		Drumkit *pInfo = Drumkit::load( absPath, false );
 		if (pInfo) {
 			__user_drumkit_info_list.push_back( pInfo );
 			QTreeWidgetItem* pDrumkitItem = new QTreeWidgetItem( __user_drumkits_item );
 			pDrumkitItem->setText( 0, pInfo->get_name() );
 			if ( QString(pInfo->get_name() ) == currentSL ){
-				pDrumkitItem->setBackgroundColor( 0, QColor( 50, 50, 50) );
+				pDrumkitItem->setBackground( 0, QColor( 50, 50, 50) );
 			}
 			InstrumentList *pInstrList = pInfo->get_instruments();
 			for ( uint nInstr = 0; nInstr < pInstrList->size(); ++nInstr ) {
@@ -200,16 +205,16 @@ void SoundLibraryPanel::updateDrumkitList()
 	}
 
 	//System drumkit list
-	QStringList sys_dks = Filesystem::sys_drumkits_list();
+	QStringList sys_dks = Filesystem::sys_drumkit_list();
 	for (int i = 0; i < sys_dks.size(); ++i) {
-		QString absPath = Filesystem::sys_drumkits_dir() + "/" + sys_dks[i];
-		Drumkit *pInfo = Drumkit::load( absPath );
+		QString absPath = Filesystem::sys_drumkits_dir() + sys_dks[i];
+		Drumkit *pInfo = Drumkit::load( absPath, false );
 		if (pInfo) {
 			__system_drumkit_info_list.push_back( pInfo );
 			QTreeWidgetItem* pDrumkitItem = new QTreeWidgetItem( __system_drumkits_item );
 			pDrumkitItem->setText( 0, pInfo->get_name() );
 			if ( QString( pInfo->get_name() ) == currentSL ){
-				pDrumkitItem->setBackgroundColor( 0, QColor( 50, 50, 50) );
+				pDrumkitItem->setBackground( 0, QColor( 50, 50, 50) );
 			}
 			InstrumentList *pInstrList = pInfo->get_instruments();
 			for ( uint nInstr = 0; nInstr < pInstrList->size(); ++nInstr ) {
@@ -222,12 +227,12 @@ void SoundLibraryPanel::updateDrumkitList()
 	}
 	
 	//Songlist
-	QStringList songs = Filesystem::songs_list();
+	QStringList songs = Filesystem::song_list_cleared();
 	if ( songs.size() > 0 ) {
 		__song_item = new QTreeWidgetItem( __sound_library_tree );
-		__song_item->setText( 0, trUtf8( "Songs" ) );
-		__song_item->setToolTip( 0, "double click to expand the list" );
-		__sound_library_tree->setItemExpanded( __song_item, __expand_songs_list );
+		__song_item->setText( 0, tr( "Songs" ) );
+		__song_item->setToolTip( 0, tr("Double click to expand the list") );
+		__song_item->setExpanded( __expand_songs_list );
 		for (uint i = 0; i < songs.size(); i++) {
 			QTreeWidgetItem* pSongItem = new QTreeWidgetItem( __song_item );
 			QString song = songs[i];
@@ -238,21 +243,15 @@ void SoundLibraryPanel::updateDrumkitList()
 
 
 	//Pattern list
-	std::vector<QString> patternDirList = mng.getPatternDirList();
+	QStringList patternDirList = Filesystem::pattern_drumkits();
 	if ( patternDirList.size() > 0 ) {
 		
 		__pattern_item = new QTreeWidgetItem( __sound_library_tree );
-		__pattern_item->setText( 0, trUtf8( "Patterns" ) );
-		__pattern_item->setToolTip( 0, "double click to expand the list" );
-		__sound_library_tree->setItemExpanded( __pattern_item, __expand_pattern_list );
-			
-		//this is to push the mng.getPatternList in all patterns/drumkit dirs
-		for (uint i = 0; i < patternDirList.size(); ++i) {
-			QString absPath =  patternDirList[i];
-			mng.getPatternList( absPath );
-		}
+		__pattern_item->setText( 0, tr( "Patterns" ) );
+		__pattern_item->setToolTip( 0, tr("Double click to expand the list") );
+		__pattern_item->setExpanded( __expand_pattern_list );
 		
-		//this is the second step to push the mng.funktion
+		//this is the second step to push the mng.function
 		//SoundLibraryDatabase::create_instance();
 		SoundLibraryDatabase* db = SoundLibraryDatabase::get_instance();
 		soundLibraryInfoVector* allPatternDirList = db->getAllPatterns();
@@ -288,8 +287,19 @@ void SoundLibraryPanel::updateDrumkitList()
 
 void SoundLibraryPanel::on_DrumkitList_ItemChanged( QTreeWidgetItem * current, QTreeWidgetItem * previous )
 {
-	UNUSED( current );
 	UNUSED( previous );
+	
+	if( current == nullptr ){
+		return;
+	}
+
+	if ( current->parent() == __system_drumkits_item ||
+		 current->parent() == __user_drumkits_item  ){
+			emit item_changed( true );
+	} else {
+		emit item_changed( false );
+	}
+	
 	test_expandedItems();
 }
 
@@ -308,6 +318,7 @@ void SoundLibraryPanel::on_DrumkitList_itemActivated( QTreeWidgetItem * item, in
 		// e' stato selezionato un drumkit
 	}
 	else {
+
 		// e' stato selezionato uno strumento
 		QString selectedName = item->text(0);
 		if( item->text(0) == "Patterns" ) return;
@@ -331,11 +342,12 @@ void SoundLibraryPanel::on_DrumkitList_itemActivated( QTreeWidgetItem * item, in
 
 void SoundLibraryPanel::on_DrumkitList_rightClicked( QPoint pos )
 {
-	if( __sound_library_tree->currentItem() == NULL )
+	if( __sound_library_tree->currentItem() == nullptr ) {
 		return;
+	}
 	
 	if (
-		( __sound_library_tree->currentItem()->parent() == NULL ) ||
+		( __sound_library_tree->currentItem()->parent() == nullptr ) ||
 		( __sound_library_tree->currentItem() == __user_drumkits_item ) ||
 		( __sound_library_tree->currentItem() == __system_drumkits_item )
 	) {
@@ -346,7 +358,7 @@ void SoundLibraryPanel::on_DrumkitList_rightClicked( QPoint pos )
 		__song_menu->popup( pos );
 	}
 
-	if ( __sound_library_tree->currentItem()->parent()->parent() == __pattern_item && __pattern_item != NULL ) {
+	if ( __sound_library_tree->currentItem()->parent()->parent() == __pattern_item && __pattern_item != nullptr ) {
 		__pattern_menu->popup( pos );
 	}
 
@@ -403,12 +415,12 @@ void SoundLibraryPanel::on_DrumkitList_mouseMove( QMouseEvent *event)
 	else {
 		//INFOLOG( "ho selezionato uno strumento" );
 		// instrument selection
-		if ( __sound_library_tree->currentItem() == NULL )
+		if ( __sound_library_tree->currentItem() == nullptr )
 		{
 			return;
 		}
 		
-		if ( __sound_library_tree->currentItem()->parent() == NULL )
+		if ( __sound_library_tree->currentItem()->parent() == nullptr )
 		{
 			return;
 		}
@@ -418,7 +430,7 @@ void SoundLibraryPanel::on_DrumkitList_mouseMove( QMouseEvent *event)
 			return;
 		}
 
-		if ( __sound_library_tree->currentItem()->parent()->text(0) == NULL )
+		if ( __sound_library_tree->currentItem()->parent()->text(0) == nullptr )
 		{
 			return;
 		}
@@ -438,7 +450,7 @@ void SoundLibraryPanel::on_DrumkitList_mouseMove( QMouseEvent *event)
 
 			pMimeData->setText( sText );
 			pDrag->setMimeData( pMimeData);
-			pDrag->start( Qt::CopyAction | Qt::MoveAction );
+			pDrag->exec( Qt::CopyAction | Qt::MoveAction );
 			return;
 		}
 
@@ -453,7 +465,7 @@ void SoundLibraryPanel::on_DrumkitList_mouseMove( QMouseEvent *event)
 		pMimeData->setText( sText );
 		pDrag->setMimeData( pMimeData);
 
-		pDrag->start( Qt::CopyAction | Qt::MoveAction );
+		pDrag->exec( Qt::CopyAction | Qt::MoveAction );
 	}
 }
 
@@ -465,13 +477,13 @@ void SoundLibraryPanel::on_drumkitLoadAction()
 
 	QString sDrumkitName = __sound_library_tree->currentItem()->text(0);
 
-	Drumkit *drumkitInfo = NULL;
+	Drumkit *pDrumkitInfo = nullptr;
 
 	// find the drumkit in the list
 	for ( uint i = 0; i < __system_drumkit_info_list.size(); i++ ) {
 		Drumkit *pInfo = __system_drumkit_info_list[i];
 		if ( pInfo->get_name() == sDrumkitName ) {
-			drumkitInfo = pInfo;
+			pDrumkitInfo = pInfo;
 			break;
 		}
 	}
@@ -479,13 +491,17 @@ void SoundLibraryPanel::on_drumkitLoadAction()
 	for ( uint i = 0; i < __user_drumkit_info_list.size(); i++ ) {
 		Drumkit *pInfo = __user_drumkit_info_list[i];
 		if ( pInfo->get_name() == sDrumkitName ) {
-			drumkitInfo = pInfo;
+			pDrumkitInfo = pInfo;
 			break;
 		}
 	}
+	
+	if( !pDrumkitInfo ) {
+		return;
+	}
 
 	InstrumentList *pSongInstrList = Hydrogen::get_instance()->getSong()->get_instrument_list();
-	InstrumentList *pDrumkitInstrList = drumkitInfo->get_instruments();
+	InstrumentList *pDrumkitInstrList = pDrumkitInfo->get_instruments();
 
 	int oldCount = pSongInstrList->size();
 	int newCount = pDrumkitInstrList->size();
@@ -493,14 +509,13 @@ void SoundLibraryPanel::on_drumkitLoadAction()
 	bool conditionalLoad = false;
 	bool hasNotes = false;
 
-	INFOLOG("Old kit has " + QString::number( oldCount ) + " intruments, new one has " + QString::number( newCount ) );
+	INFOLOG("Old kit has " + QString::number( oldCount ) + " instruments, new one has " + QString::number( newCount ) );
 
 	if ( newCount < oldCount )
 	{
 		// Check if any of the instruments that will be removed have notes
 		for ( int i = 0; i < pSongInstrList->size(); i++)
 		{
-			
 			if ( i >= newCount )
 			{
 				INFOLOG("Checking if Instrument " + QString::number( i ) + " has notes..." );
@@ -509,7 +524,6 @@ void SoundLibraryPanel::on_drumkitLoadAction()
 				{
 					hasNotes = true;
 					INFOLOG("Instrument " + QString::number( i ) + " has notes" );
-
 				}
 			}
 
@@ -520,10 +534,10 @@ void SoundLibraryPanel::on_drumkitLoadAction()
 			QMessageBox msgBox;
 			msgBox.setWindowTitle("Hydrogen");
 			msgBox.setIcon( QMessageBox::Warning );
-			msgBox.setText( tr( "The existing kit has %1 instruments but the new one only has %2.\nThe first %2 instruments will be replaced with the new intruments and will keep their notes, but some of the remaining instruments have notes.\nWould you like to keep or discard the remaining instruments and notes?\n").arg( QString::number( oldCount ),QString::number( newCount ) ) );
+			msgBox.setText( tr( "The existing kit has %1 instruments but the new one only has %2.\nThe first %2 instruments will be replaced with the new instruments and will keep their notes, but some of the remaining instruments have notes.\nWould you like to keep or discard the remaining instruments and notes?\n").arg( QString::number( oldCount ),QString::number( newCount ) ) );
 
 			msgBox.setStandardButtons(QMessageBox::Save);
-			msgBox.setButtonText(QMessageBox::Save, trUtf8("Keep"));
+			msgBox.setButtonText(QMessageBox::Save, tr("Keep"));
 			msgBox.addButton(QMessageBox::Discard);
 			msgBox.addButton(QMessageBox::Cancel);
 			msgBox.setDefaultButton(QMessageBox::Cancel);
@@ -548,20 +562,19 @@ void SoundLibraryPanel::on_drumkitLoadAction()
 	}
 
 
-	assert( drumkitInfo );
+	assert( pDrumkitInfo );
 
 	QApplication::setOverrideCursor(Qt::WaitCursor);
 
-
-	Hydrogen::get_instance()->loadDrumkit( drumkitInfo, conditionalLoad );
+	Hydrogen::get_instance()->loadDrumkit( pDrumkitInfo, conditionalLoad );
 	Hydrogen::get_instance()->getSong()->set_is_modified( true );
-	HydrogenApp::get_instance()->onDrumkitLoad( drumkitInfo->get_name() );
+	HydrogenApp::get_instance()->onDrumkitLoad( pDrumkitInfo->get_name() );
 	HydrogenApp::get_instance()->getPatternEditorPanel()->getDrumPatternEditor()->updateEditor();
 	HydrogenApp::get_instance()->getPatternEditorPanel()->updatePianorollEditor();
 
 	InstrumentEditorPanel::get_instance()->notifyOfDrumkitChange();
 
-	__sound_library_tree->currentItem()->setBackgroundColor ( 0, QColor( 50, 50, 50) );
+	__sound_library_tree->currentItem()->setBackground( 0, QColor( 50, 50, 50) );
 	QApplication::restoreOverrideCursor();
 
 }
@@ -591,18 +604,18 @@ void SoundLibraryPanel::restore_background_color()
 
 void SoundLibraryPanel::change_background_color()
 {
-	QString curlib =  Hydrogen::get_instance()->getCurrentDrumkitname();
- 
+	QString sCurDrumkitName =  Hydrogen::get_instance()->getCurrentDrumkitname();
+
 	for (int i = 0; i < __system_drumkits_item->childCount() ; i++){
-		if ( ( __system_drumkits_item->child( i ) )->text( 0 ) == curlib ){
-			( __system_drumkits_item->child( i ) )->setBackgroundColor ( 0, QColor( 50, 50, 50)  );
+		if ( ( __system_drumkits_item->child( i ) )->text( 0 ) == sCurDrumkitName ){
+			( __system_drumkits_item->child( i ) )->setBackground( 0, QColor( 50, 50, 50)  );
 			break;
 		}
 	}
 
 	for (int i = 0; i < __user_drumkits_item->childCount() ; i++){
-		if ( ( __user_drumkits_item->child( i ))->text( 0 ) == curlib ){
-			( __user_drumkits_item->child( i ) )->setBackgroundColor ( 0, QColor( 50, 50, 50)  );
+		if ( ( __user_drumkits_item->child( i ))->text( 0 ) == sCurDrumkitName ){
+			( __user_drumkits_item->child( i ) )->setBackground( 0, QColor( 50, 50, 50)  );
 			break;
 		}
 	}
@@ -612,32 +625,34 @@ void SoundLibraryPanel::change_background_color()
 
 void SoundLibraryPanel::on_drumkitDeleteAction()
 {
-	QTreeWidgetItem* item = __sound_library_tree->currentItem();
+	QTreeWidgetItem* pItem = __sound_library_tree->currentItem();
 	QString itemName = QString("%1").arg(__sound_library_tree->currentItem()->text(0));
 
 	//if we delete the current loaded drumkit we can get trouble with some empty pointers
 	// TODO this check is really unsafe
-	if ( item->text(0) == Hydrogen::get_instance()->getCurrentDrumkitname() ){
+	if ( pItem->text(0) == Hydrogen::get_instance()->getCurrentDrumkitname() ){
 		QMessageBox::warning( this, "Hydrogen", tr( "It is not possible to delete the currently loaded drumkit: \n  \"%1\".\nTo delete this drumkit first load another drumkit.").arg(itemName) );
 		return;
 	}
 
-	if ( item->parent() == __system_drumkits_item ) {
+	if ( pItem->parent() == __system_drumkits_item ) {
 		QMessageBox::warning( this, "Hydrogen", tr( "\"%1\"is a system drumkit and can't be deleted.").arg(itemName) );
 		return;
 	}
 
-	int res = QMessageBox::warning( this, "Hydrogen", tr( "Warning, the \"%1\" drumkit will be deleted from disk.\nAre you sure?").arg(itemName), "&Ok", "&Cancel", 0, 1 );
+	int res = QMessageBox::warning( this, "Hydrogen", tr( "Warning, the \"%1\" drumkit will be deleted from disk.\nAre you sure?").arg(itemName), "&Ok", "&Cancel", nullptr, 1 );
 	if ( res == 1 ) {
 		return;
 	}
 
 	QApplication::setOverrideCursor(Qt::WaitCursor);
-	bool success = Drumkit::remove( item->text(0) );
+	bool success = Drumkit::remove( pItem->text(0) );
 	test_expandedItems();
 	updateDrumkitList();
 	QApplication::restoreOverrideCursor();
-	if ( !success) QMessageBox::warning( this, "Hydrogen", tr( "Drumkit deletion failed.") );
+	if ( !success) {
+		QMessageBox::warning( this, "Hydrogen", tr( "Drumkit deletion failed.") );
+	}
 }
 
 
@@ -655,7 +670,7 @@ void SoundLibraryPanel::on_drumkitPropertiesAction()
 {
 	QString sDrumkitName = __sound_library_tree->currentItem()->text(0);
 
-	Drumkit *drumkitInfo = NULL;
+	Drumkit *drumkitInfo = nullptr;
 
 	// find the drumkit in the list
 	for ( uint i = 0; i < __system_drumkit_info_list.size(); i++ ) {
@@ -677,7 +692,7 @@ void SoundLibraryPanel::on_drumkitPropertiesAction()
 
 	QString sPreDrumkitName = Hydrogen::get_instance()->getCurrentDrumkitname();
 
-	Drumkit *preDrumkitInfo = NULL;
+	Drumkit *preDrumkitInfo = nullptr;
 	
 
 	// find the drumkit in the list
@@ -696,13 +711,13 @@ void SoundLibraryPanel::on_drumkitPropertiesAction()
 		}
 	}
 
-	if ( preDrumkitInfo == NULL ){
+	if ( preDrumkitInfo == nullptr ){
 		QMessageBox::warning( this, "Hydrogen", QString( "The current loaded song missing his soundlibrary.\nPlease load a existing soundlibrary first") );
 		return;
 	}
 	assert( preDrumkitInfo );
 	
-	//open the soundlibrary save dialog 
+	//open the soundlibrary save dialog
 	SoundLibraryPropertiesDialog dialog( this , drumkitInfo, preDrumkitInfo );
 	dialog.exec();
 }
@@ -717,11 +732,7 @@ void SoundLibraryPanel::on_instrumentDeleteAction()
 
 void SoundLibraryPanel::on_songLoadAction()
 {
-	QString songName = __sound_library_tree->currentItem()->text( 0 );
-	QString sDirectory = Preferences::get_instance()->getDataDirectory()  + "songs";
-
-	QString sFilename = sDirectory + "/" + songName + ".h2song";
-	
+	QString sFilename = Filesystem::song_path( __sound_library_tree->currentItem()->text( 0 ) );
 
 	Hydrogen *pHydrogen = Hydrogen::get_instance();
 	if ( pHydrogen->getState() == STATE_PLAYING ) {
@@ -729,8 +740,8 @@ void SoundLibraryPanel::on_songLoadAction()
 	}
 
 	Song *pSong = Song::load( sFilename );
-	if ( pSong == NULL ) {
-		QMessageBox::information( this, "Hydrogen", trUtf8("Error loading song.") );
+	if ( pSong == nullptr ) {
+		QMessageBox::information( this, "Hydrogen", tr("Error loading song.") );
 		return;
 	}
 
@@ -755,40 +766,21 @@ void SoundLibraryPanel::on_patternLoadAction()
 {
 	LocalFileMng mng;
 
-	QString patternName = __sound_library_tree->currentItem()->text( 0 ) + ".h2pattern";
-	QString drumkitname = __sound_library_tree->currentItem()->toolTip ( 0 );
 	Hydrogen *pHydrogen = Hydrogen::get_instance();
 	Song *pSong = pHydrogen->getSong();
 	PatternList *pPatternList = pSong->get_pattern_list();
+	QString patternName = __sound_library_tree->currentItem()->text( 0 );
+	QString drumkitName = __sound_library_tree->currentItem()->toolTip ( 0 );
 	
-	QString sDirectory;
+	// FIXME : file path should come from the selected item
+	Pattern* pErr = Pattern::load_file( Filesystem::pattern_path( drumkitName, patternName ), pSong->get_instrument_list() );
 
-	std::vector<QString> patternDirList = mng.getPatternDirList();
-
-	for (uint i = 0; i < patternDirList.size(); ++i) {
-		QString absPath =  patternDirList[i];
-		mng.getPatternList( absPath );
-	}
-
-	std::vector<QString> allPatternDirList = mng.getallPatternList();
-
-	for (uint i = 0; i < allPatternDirList.size(); ++i) {
-		QString testName = allPatternDirList[i];
-		if( testName.contains( patternName ) && testName.contains( drumkitname )){
-			sDirectory = allPatternDirList[i];		
-		} 
-	}
-
-	Pattern* pErr = mng.loadPattern (sDirectory );
-
-	if ( pErr == 0 ) {
+	if ( pErr == nullptr ) {
 		ERRORLOG( "Error loading the pattern" );
+		return;
 	}
-	else {
-		pPatternList->add ( pErr );
-		pSong->set_is_modified( true );
-	}
-
+	pPatternList->add ( pErr );
+	pSong->set_is_modified( true );
 	HydrogenApp::get_instance()->getSongEditorPanel()->updateAll();
 }
 
@@ -797,7 +789,7 @@ void SoundLibraryPanel::on_patternDeleteAction()
 {
 	QString patternPath = __sound_library_tree->currentItem()->text( 1 );
 
-	int res = QMessageBox::information( this, "Hydrogen", tr( "Warning, the selected pattern will be deleted from disk.\nAre you sure?"), tr("&Ok"), tr("&Cancel"), 0, 1 );
+	int res = QMessageBox::information( this, "Hydrogen", tr( "Warning, the selected pattern will be deleted from disk.\nAre you sure?"), tr("&Ok"), tr("&Cancel"), nullptr, 1 );
 	if ( res == 1 ) {
 		return;
 	}
@@ -817,8 +809,16 @@ void SoundLibraryPanel::on_patternDeleteAction()
 void SoundLibraryPanel::test_expandedItems()
 {
 	assert( __sound_library_tree );
-	__expand_songs_list = __sound_library_tree->isItemExpanded( __song_item );
-	__expand_pattern_list = __sound_library_tree->isItemExpanded( __pattern_item );
+	if ( __song_item == nullptr) {
+		__expand_songs_list = false;
+	} else {
+		__expand_songs_list = __song_item->isExpanded();
+	}
+	if ( __pattern_item == nullptr) {
+		__expand_pattern_list = false;
+	} else {
+		__expand_pattern_list = __pattern_item->isExpanded();
+	}
 	Preferences::get_instance()->__expandSongItem = __expand_songs_list;
 	Preferences::get_instance()->__expandPatternItem = __expand_pattern_list;
 	//ERRORLOG( QString("songs %1 patterns %2").arg(__expand_songs_list).arg(__expand_pattern_list) );
