@@ -26,7 +26,6 @@
 
 #include <hydrogen/object.h>
 #include <hydrogen/hydrogen.h>
-#include <hydrogen/LocalFileMng.h>
 #include <hydrogen/Preferences.h>
 #include <hydrogen/fx/Effects.h>
 #include <hydrogen/event_queue.h>
@@ -37,7 +36,7 @@
 using std::cout;
 using std::endl;
 
-#include <QApplication>
+#include <QCoreApplication>
 
 void usage()
 {
@@ -53,7 +52,7 @@ int main(int argc, char** argv){
 	H2Core::Logger* logger = H2Core::Logger::get_instance();
 	H2Core::Object::bootstrap( logger, logger->should_log(H2Core::Logger::Debug) );
 
-	QApplication a(argc, argv);
+	QCoreApplication a(argc, argv);
 
 	H2Core::Filesystem::bootstrap( logger );
 
@@ -70,7 +69,7 @@ int main(int argc, char** argv){
 	H2Core::Preferences *preferences = H2Core::Preferences::get_instance();
 
 	H2Core::Song *pSong = H2Core::Song::load( filename );
-	if (pSong == NULL) {
+	if (pSong == nullptr) {
 		cout << "Error loading song!" << endl;
 		exit(2);
 	}
